import pytest

from botcity.plugins.cloudvision.plugin import BotCloudVisionPlugin

PATH_PNG = "./examples/test_vision.png"
PATH_PDF = "./examples/test_vision.pdf"
PATH_TXT = "./examples/test_vision.txt"


def test_type_error(bot: BotCloudVisionPlugin):
    with pytest.raises(ValueError):
        bot.read(filepath=PATH_TXT)


def test_read_png(bot: BotCloudVisionPlugin):
    bot.read(filepath=PATH_PNG)
    full_text = bot.full_text()
    assert full_text == '\nA Simple PDF File\nThis is a small demonstration .pdf file -\njust for use in the Virtual Mechanics tutorials. More text. And more\ntext. And more text. And more text. And more text.\nAnd more text. And more text. And more text. And more text. And more\ntext. And more text. Boring, zzzzz. And more text. And more text. And\nmore text. And more text. And more text. And more text. And more text.\nAnd more text. And more text.\nAnd more text. And more text. And more text. And more text. And more\ntext. And more text. And more text. Even more. Continued on page 2\nSimple PDF File 2\n...continued from page 1. Yet more text. And more text. And more text.\nAnd more text. And more text. And more text. And more text. And more\ntext. Oh, how boring typing this stuff. But not as boring as watching\npaint dry. And more text. And more text. And more text. And more text.\nBoring. More, a little more text. The end, and just as well.'


def test_set_rate(bot: BotCloudVisionPlugin):
    response = bot.set_render_rate(rate=82)
    assert isinstance(response, BotCloudVisionPlugin)
    assert bot.render_rate() == 82
    bot.set_render_rate(rate=72)


def test_set_threshold(bot: BotCloudVisionPlugin):
    bot.set_threshold(threshold=82)
    assert bot.threshold() == 82
    bot.set_threshold(threshold=None)


@pytest.mark.depends(name="test_read_png")
def test_render_rate_png(bot: BotCloudVisionPlugin):
    assert bot.render_rate() == 72


@pytest.mark.depends(name="test_read_png")
def test_threshold_png(bot: BotCloudVisionPlugin):
    assert bot.threshold() is None


@pytest.mark.depends(name="test_read_png")
def test_entries_png(bot: BotCloudVisionPlugin):
    entries = bot.entries()
    assert entries == [['A', 178, 140, 225, 139, 226, 204, 179, 205, 1],
                       ['Simple', 252, 138, 474, 134, 475, 199, 253, 203, 1],
                       ['PDF', 504, 134, 645, 131, 646, 196, 505, 199, 1],
                       ['File', 675, 130, 788, 128, 789, 194, 676, 196, 1],
                       ['This', 200, 266, 252, 266, 252, 292, 200, 292, 1],
                       ['is', 261, 266, 279, 266, 279, 292, 261, 292, 1],
                       ['a', 288, 266, 303, 266, 303, 292, 288, 292, 1],
                       ['small', 311, 266, 376, 266, 376, 292, 311, 292, 1],
                       ['demonstration', 384, 266, 557, 266, 557, 292, 384, 292, 1],
                       ['.pdf', 569, 266, 613, 266, 613, 292, 569, 292, 1],
                       ['file', 621, 266, 656, 266, 656, 292, 621, 292, 1],
                       ['-', 665, 266, 674, 266, 674, 292, 665, 292, 1],
                       ['just', 198, 332, 244, 332, 244, 357, 198, 357, 1],
                       ['for', 249, 332, 284, 332, 284, 357, 249, 357, 1],
                       ['use', 291, 332, 334, 332, 334, 357, 291, 357, 1],
                       ['in', 344, 332, 363, 332, 363, 357, 344, 357, 1],
                       ['the', 372, 332, 410, 332, 410, 357, 372, 357, 1],
                       ['Virtual', 420, 332, 497, 332, 497, 357, 420, 357, 1],
                       ['Mechanics', 508, 332, 636, 332, 636, 357, 508, 357, 1],
                       ['tutorials', 645, 332, 741, 332, 741, 357, 645, 357, 1],
                       ['.', 746, 332, 750, 332, 750, 357, 746, 357, 1],
                       ['More', 761, 332, 820, 332, 820, 357, 761, 357, 1],
                       ['text', 830, 332, 874, 332, 874, 357, 830, 357, 1],
                       ['.', 877, 332, 880, 332, 880, 357, 877, 357, 1],
                       ['And', 890, 332, 936, 332, 936, 357, 890, 357, 1],
                       ['more', 949, 332, 1010, 332, 1010, 357, 949, 357, 1],
                       ['text', 198, 366, 244, 366, 244, 387, 198, 387, 1],
                       ['.', 247, 366, 251, 366, 251, 387, 247, 387, 1],
                       ['And', 260, 366, 309, 366, 309, 387, 260, 387, 1],
                       ['more', 318, 366, 379, 366, 379, 387, 318, 387, 1],
                       ['text', 388, 366, 433, 366, 433, 387, 388, 387, 1],
                       ['.', 435, 366, 438, 366, 438, 387, 435, 387, 1],
                       ['And', 449, 366, 495, 366, 495, 387, 449, 387, 1],
                       ['more', 507, 366, 567, 366, 567, 387, 507, 387, 1],
                       ['text', 576, 366, 621, 366, 621, 387, 576, 387, 1],
                       ['.', 624, 366, 627, 366, 627, 387, 624, 387, 1],
                       ['And', 637, 366, 684, 366, 684, 387, 637, 387, 1],
                       ['more', 695, 366, 756, 366, 756, 387, 695, 387, 1],
                       ['text', 764, 366, 810, 366, 810, 387, 764, 387, 1],
                       ['.', 812, 366, 816, 366, 816, 387, 812, 387, 1],
                       ['And', 198, 432, 248, 432, 248, 453, 198, 453, 1],
                       ['more', 258, 432, 318, 432, 318, 453, 258, 453, 1],
                       ['text', 327, 432, 372, 432, 372, 453, 327, 453, 1],
                       ['.', 375, 432, 378, 432, 378, 453, 375, 453, 1],
                       ['And', 388, 432, 435, 432, 435, 453, 388, 453, 1],
                       ['more', 447, 432, 507, 432, 507, 453, 447, 453, 1],
                       ['text', 516, 432, 561, 432, 561, 453, 516, 453, 1],
                       ['.', 564, 432, 567, 432, 567, 453, 564, 453, 1],
                       ['And', 577, 432, 624, 432, 624, 453, 577, 453, 1],
                       ['more', 635, 432, 695, 432, 695, 453, 635, 453, 1],
                       ['text', 704, 432, 749, 432, 749, 453, 704, 453, 1],
                       ['.', 752, 432, 755, 432, 755, 453, 752, 453, 1],
                       ['And', 765, 432, 811, 432, 811, 453, 765, 453, 1],
                       ['more', 824, 432, 884, 432, 884, 453, 824, 453, 1],
                       ['text', 893, 432, 938, 432, 938, 453, 893, 453, 1],
                       ['.', 940, 432, 943, 432, 943, 453, 940, 453, 1],
                       ['And', 954, 432, 1001, 432, 1001, 453, 954, 453, 1],
                       ['more', 1011, 432, 1073, 432, 1073, 453, 1011, 453, 1],
                       ['text', 199, 466, 245, 466, 245, 490, 199, 490, 1],
                       ['.', 247, 466, 251, 466, 251, 490, 247, 490, 1],
                       ['And', 260, 466, 307, 466, 307, 490, 260, 490, 1],
                       ['more', 319, 466, 380, 466, 380, 490, 319, 490, 1],
                       ['text', 388, 466, 432, 466, 432, 490, 388, 490, 1],
                       ['.', 435, 466, 438, 466, 438, 490, 435, 490, 1],
                       ['Boring', 450, 466, 526, 466, 526, 490, 450, 490, 1],
                       [',', 531, 466, 535, 466, 535, 490, 531, 490, 1],
                       ['zzzzz', 545, 466, 612, 466, 612, 490, 545, 490, 1],
                       ['.', 616, 466, 620, 466, 620, 490, 616, 490, 1],
                       ['And', 629, 466, 675, 466, 675, 490, 629, 490, 1],
                       ['more', 688, 466, 748, 466, 748, 490, 688, 490, 1],
                       ['text', 757, 466, 801, 466, 801, 490, 757, 490, 1],
                       ['.', 805, 466, 807, 466, 807, 490, 805, 490, 1],
                       ['And', 818, 466, 865, 466, 865, 490, 818, 490, 1],
                       ['more', 877, 466, 936, 466, 936, 490, 877, 490, 1],
                       ['text', 944, 466, 990, 466, 990, 490, 944, 490, 1],
                       ['.', 993, 466, 997, 466, 997, 490, 993, 490, 1],
                       ['And', 1006, 466, 1053, 466, 1053, 490, 1006, 490, 1],
                       ['more', 200, 499, 261, 499, 261, 519, 200, 519, 1],
                       ['text', 269, 499, 316, 499, 316, 519, 269, 519, 1],
                       ['.', 318, 499, 322, 499, 322, 519, 318, 519, 1],
                       ['And', 331, 499, 378, 499, 378, 519, 331, 519, 1],
                       ['more', 390, 499, 450, 499, 450, 519, 390, 519, 1],
                       ['text', 459, 499, 503, 499, 503, 519, 459, 519, 1],
                       ['.', 507, 499, 510, 499, 510, 519, 507, 519, 1],
                       ['And', 520, 499, 566, 499, 566, 519, 520, 519, 1],
                       ['more', 578, 499, 638, 499, 638, 519, 578, 519, 1],
                       ['text', 647, 499, 692, 499, 692, 519, 647, 519, 1],
                       ['.', 695, 499, 698, 499, 698, 519, 695, 519, 1],
                       ['And', 709, 499, 755, 499, 755, 519, 709, 519, 1],
                       ['more', 766, 499, 827, 499, 827, 519, 766, 519, 1],
                       ['text', 835, 499, 881, 499, 881, 519, 835, 519, 1],
                       ['.', 883, 499, 886, 499, 886, 519, 883, 519, 1],
                       ['And', 896, 499, 943, 499, 943, 519, 896, 519, 1],
                       ['more', 955, 499, 1015, 499, 1015, 519, 955, 519, 1],
                       ['text', 1023, 499, 1069, 499, 1069, 519, 1023, 519, 1],
                       ['.', 1071, 499, 1075, 499, 1075, 519, 1071, 519, 1],
                       ['And', 199, 532, 248, 532, 248, 553, 199, 553, 1],
                       ['more', 257, 532, 318, 532, 318, 553, 257, 553, 1],
                       ['text', 326, 532, 373, 532, 373, 553, 326, 553, 1],
                       ['.', 375, 532, 378, 532, 378, 553, 375, 553, 1],
                       ['And', 388, 532, 435, 532, 435, 553, 388, 553, 1],
                       ['more', 447, 532, 507, 532, 507, 553, 447, 553, 1],
                       ['text', 515, 532, 561, 532, 561, 553, 515, 553, 1],
                       ['.', 563, 532, 567, 532, 567, 553, 563, 553, 1],
                       ['And', 199, 599, 248, 599, 248, 619, 199, 619, 1],
                       ['more', 258, 599, 318, 599, 318, 619, 258, 619, 1],
                       ['text', 327, 599, 372, 599, 372, 619, 327, 619, 1],
                       ['.', 375, 599, 378, 599, 378, 619, 375, 619, 1],
                       ['And', 388, 599, 435, 599, 435, 619, 388, 619, 1],
                       ['more', 447, 599, 507, 599, 507, 619, 447, 619, 1],
                       ['text', 516, 599, 560, 599, 560, 619, 516, 619, 1],
                       ['.', 564, 599, 567, 599, 567, 619, 564, 619, 1],
                       ['And', 577, 599, 624, 599, 624, 619, 577, 619, 1],
                       ['more', 636, 599, 696, 599, 696, 619, 636, 619, 1],
                       ['text', 704, 599, 750, 599, 750, 619, 704, 619, 1],
                       ['.', 752, 599, 755, 599, 755, 619, 752, 619, 1],
                       ['And', 765, 599, 811, 599, 811, 619, 765, 619, 1],
                       ['more', 824, 599, 883, 599, 883, 619, 824, 619, 1],
                       ['text', 893, 599, 937, 599, 937, 619, 893, 619, 1],
                       ['.', 941, 599, 944, 599, 944, 619, 941, 619, 1],
                       ['And', 954, 599, 1001, 599, 1001, 619, 954, 619, 1],
                       ['more', 1011, 599, 1073, 599, 1073, 619, 1011, 619, 1],
                       ['text', 198, 632, 244, 632, 244, 657, 198, 657, 1],
                       ['.', 247, 632, 251, 632, 251, 657, 247, 657, 1],
                       ['And', 260, 632, 308, 632, 308, 657, 260, 657, 1],
                       ['more', 318, 632, 379, 632, 379, 657, 318, 657, 1],
                       ['text', 388, 632, 433, 632, 433, 657, 388, 657, 1],
                       ['.', 436, 632, 439, 632, 439, 657, 436, 657, 1],
                       ['And', 449, 632, 495, 632, 495, 657, 449, 657, 1],
                       ['more', 507, 632, 567, 632, 567, 657, 507, 657, 1],
                       ['text', 577, 632, 620, 632, 620, 657, 577, 657, 1],
                       ['.', 624, 632, 627, 632, 627, 657, 624, 657, 1],
                       ['Even', 640, 632, 698, 632, 698, 657, 640, 657, 1],
                       ['more', 710, 632, 769, 632, 769, 657, 710, 657, 1],
                       ['.', 774, 632, 778, 632, 778, 657, 774, 657, 1],
                       ['Continued', 788, 632, 910, 632, 910, 657, 788, 657, 1],
                       ['on', 922, 632, 949, 632, 949, 657, 922, 657, 1],
                       ['page', 960, 632, 1020, 632, 1020, 657, 960, 657, 1],
                       ['2', 1029, 632, 1043, 632, 1043, 657, 1029, 657, 1],
                       ['Simple', 196, 751, 418, 747, 419, 815, 197, 819, 1],
                       ['PDF', 445, 747, 587, 744, 588, 811, 446, 814, 1],
                       ['File', 613, 743, 734, 741, 735, 809, 614, 811, 1],
                       ['2', 751, 741, 797, 740, 798, 807, 752, 808, 1],
                       ['...', 214, 882, 236, 882, 236, 907, 214, 907, 1],
                       ['continued', 237, 882, 355, 882, 355, 907, 237, 907, 1],
                       ['from', 364, 882, 418, 882, 418, 907, 364, 907, 1],
                       ['page', 429, 882, 488, 882, 488, 907, 429, 907, 1],
                       ['1.', 500, 882, 519, 882, 519, 907, 500, 907, 1],
                       ['Yet', 529, 882, 570, 882, 570, 907, 529, 907, 1],
                       ['more', 580, 882, 640, 882, 640, 907, 580, 907, 1],
                       ['text', 649, 882, 694, 882, 694, 907, 649, 907, 1],
                       ['.', 697, 882, 701, 882, 701, 907, 697, 907, 1],
                       ['And', 709, 882, 757, 882, 757, 907, 709, 907, 1],
                       ['more', 768, 882, 828, 882, 828, 907, 768, 907, 1],
                       ['text', 837, 882, 882, 882, 882, 907, 837, 907, 1],
                       ['.', 885, 882, 889, 882, 889, 907, 885, 907, 1],
                       ['And', 898, 882, 945, 882, 945, 907, 898, 907, 1],
                       ['more', 956, 882, 1017, 882, 1017, 907, 956, 907, 1],
                       ['text', 1025, 882, 1071, 882, 1071, 907, 1025, 907, 1],
                       ['.', 1072, 882, 1078, 882, 1078, 907, 1072, 907, 1],
                       ['And', 214, 915, 262, 915, 262, 936, 214, 936, 1],
                       ['more', 272, 915, 332, 915, 332, 936, 272, 936, 1],
                       ['text', 340, 915, 386, 915, 386, 936, 340, 936, 1],
                       ['.', 390, 915, 393, 915, 393, 936, 390, 936, 1],
                       ['And', 402, 915, 449, 915, 449, 936, 402, 936, 1],
                       ['more', 461, 915, 521, 915, 521, 936, 461, 936, 1],
                       ['text', 530, 915, 575, 915, 575, 936, 530, 936, 1],
                       ['.', 578, 915, 581, 915, 581, 936, 578, 936, 1],
                       ['And', 591, 915, 638, 915, 638, 936, 591, 936, 1],
                       ['more', 649, 915, 710, 915, 710, 936, 649, 936, 1],
                       ['text', 718, 915, 763, 915, 763, 936, 718, 936, 1],
                       ['.', 766, 915, 769, 915, 769, 936, 766, 936, 1],
                       ['And', 779, 915, 825, 915, 825, 936, 779, 936, 1],
                       ['more', 838, 915, 898, 915, 898, 936, 838, 936, 1],
                       ['text', 907, 915, 952, 915, 952, 936, 907, 936, 1],
                       ['.', 955, 915, 957, 915, 957, 936, 955, 936, 1],
                       ['And', 968, 915, 1014, 915, 1014, 936, 968, 936, 1],
                       ['more', 1025, 915, 1088, 915, 1088, 936, 1025, 936, 1],
                       ['text', 212, 947, 259, 947, 259, 974, 212, 974, 1],
                       ['.', 261, 947, 266, 947, 266, 974, 261, 974, 1],
                       ['Oh', 275, 947, 309, 947, 309, 974, 275, 974, 1],
                       [',', 313, 947, 318, 947, 318, 974, 313, 974, 1],
                       ['how', 327, 947, 375, 947, 375, 974, 327, 974, 1],
                       ['boring', 386, 947, 460, 947, 460, 974, 386, 974, 1],
                       ['typing', 470, 947, 542, 947, 542, 974, 470, 974, 1],
                       ['this', 551, 947, 594, 947, 594, 974, 551, 974, 1],
                       ['stuff', 604, 947, 655, 947, 655, 974, 604, 974, 1],
                       ['.', 658, 947, 660, 947, 660, 974, 658, 974, 1],
                       ['But', 673, 947, 712, 947, 712, 974, 673, 974, 1],
                       ['not', 722, 947, 758, 947, 758, 974, 722, 974, 1],
                       ['as', 768, 947, 794, 947, 794, 974, 768, 974, 1],
                       ['boring', 805, 947, 879, 947, 879, 974, 805, 974, 1],
                       ['as', 890, 947, 917, 947, 917, 974, 890, 974, 1],
                       ['watching', 926, 947, 1035, 947, 1035, 974, 926, 974, 1],
                       ['paint', 214, 981, 275, 981, 275, 1005, 214, 1005, 1],
                       ['dry', 282, 981, 320, 981, 320, 1005, 282, 1005, 1],
                       ['.', 322, 981, 328, 981, 328, 1005, 322, 1005, 1],
                       ['And', 335, 981, 383, 981, 383, 1005, 335, 1005, 1],
                       ['more', 395, 981, 454, 981, 454, 1005, 395, 1005, 1],
                       ['text', 463, 981, 508, 981, 508, 1005, 463, 1005, 1],
                       ['.', 511, 981, 515, 981, 515, 1005, 511, 1005, 1],
                       ['And', 524, 981, 571, 981, 571, 1005, 524, 1005, 1],
                       ['more', 583, 981, 643, 981, 643, 1005, 583, 1005, 1],
                       ['text', 652, 981, 696, 981, 696, 1005, 652, 1005, 1],
                       ['.', 700, 981, 704, 981, 704, 1005, 700, 1005, 1],
                       ['And', 713, 981, 760, 981, 760, 1005, 713, 1005, 1],
                       ['more', 772, 981, 831, 981, 831, 1005, 772, 1005, 1],
                       ['text', 840, 981, 885, 981, 885, 1005, 840, 1005, 1],
                       ['.', 888, 981, 891, 981, 891, 1005, 888, 1005, 1],
                       ['And', 901, 981, 948, 981, 948, 1005, 901, 1005, 1],
                       ['more', 960, 981, 1020, 981, 1020, 1005, 960, 1005, 1],
                       ['text', 1028, 981, 1074, 981, 1074, 1005, 1028, 1005, 1],
                       ['.', 1075, 981, 1081, 981, 1081, 1005, 1075, 1005, 1],
                       ['Boring', 215, 1014, 292, 1014, 292, 1040, 215, 1040, 1],
                       ['.', 296, 1014, 302, 1014, 302, 1040, 296, 1040, 1],
                       ['More', 318, 1014, 380, 1014, 380, 1040, 318, 1040, 1],
                       [',', 381, 1014, 386, 1014, 386, 1040, 381, 1040, 1],
                       ['a', 396, 1014, 409, 1014, 409, 1040, 396, 1040, 1],
                       ['little', 420, 1014, 467, 1014, 467, 1040, 420, 1040, 1],
                       ['more', 478, 1014, 538, 1014, 538, 1040, 478, 1040, 1],
                       ['text', 547, 1014, 592, 1014, 592, 1040, 547, 1040, 1],
                       ['.', 595, 1014, 598, 1014, 598, 1040, 595, 1040, 1],
                       ['The', 608, 1014, 653, 1014, 653, 1040, 608, 1040, 1],
                       ['end', 664, 1014, 708, 1014, 708, 1040, 664, 1040, 1],
                       [',', 711, 1014, 715, 1014, 715, 1040, 711, 1040, 1],
                       ['and', 725, 1014, 769, 1014, 769, 1040, 725, 1040, 1],
                       ['just', 777, 1014, 822, 1014, 822, 1040, 777, 1040, 1],
                       ['as', 830, 1014, 858, 1014, 858, 1040, 830, 1040, 1],
                       ['well', 866, 1014, 915, 1014, 915, 1040, 866, 1040, 1],
                       ['.', 916, 1014, 921, 1014, 921, 1040, 916, 1040, 1]]


@pytest.mark.depends(name="test_read_png")
def test_reset_case_png(bot: BotCloudVisionPlugin):
    bot.reset_case()
    assert not bot._to_lowercase
    assert not bot._to_uppercase


@pytest.mark.depends(name="test_reset_case_png")
def test_upper_case_png(bot: BotCloudVisionPlugin):
    bot.to_upper_case()
    assert not bot._to_lowercase
    assert bot._to_uppercase


@pytest.mark.depends(name="test_upper_case_png")
def test_read_png_uppercase(bot: BotCloudVisionPlugin):
    bot.read(filepath=PATH_PNG)
    assert bot.full_text() == '\nA SIMPLE PDF FILE\nTHIS IS A SMALL DEMONSTRATION .PDF FILE -\nJUST FOR USE IN THE VIRTUAL MECHANICS TUTORIALS. MORE TEXT. AND MORE\nTEXT. AND MORE TEXT. AND MORE TEXT. AND MORE TEXT.\nAND MORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE\nTEXT. AND MORE TEXT. BORING, ZZZZZ. AND MORE TEXT. AND MORE TEXT. AND\nMORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE TEXT.\nAND MORE TEXT. AND MORE TEXT.\nAND MORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE\nTEXT. AND MORE TEXT. AND MORE TEXT. EVEN MORE. CONTINUED ON PAGE 2\nSIMPLE PDF FILE 2\n...CONTINUED FROM PAGE 1. YET MORE TEXT. AND MORE TEXT. AND MORE TEXT.\nAND MORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE\nTEXT. OH, HOW BORING TYPING THIS STUFF. BUT NOT AS BORING AS WATCHING\nPAINT DRY. AND MORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE TEXT.\nBORING. MORE, A LITTLE MORE TEXT. THE END, AND JUST AS WELL.'


@pytest.mark.depends(name="test_upper_case_png")
def test_entries_png_uppercase(bot: BotCloudVisionPlugin):
    bot.read(filepath=PATH_PNG)
    assert bot.entries() == [['A', 178, 140, 225, 139, 226, 204, 179, 205, 1], ['Simple', 252, 138, 474, 134, 475, 199, 253, 203, 1], ['PDF', 504, 134, 645, 131, 646, 196, 505, 199, 1], ['File', 675, 130, 788, 128, 789, 194, 676, 196, 1], ['This', 200, 266, 252, 266, 252, 292, 200, 292, 1], ['is', 261, 266, 279, 266, 279, 292, 261, 292, 1], ['a', 288, 266, 303, 266, 303, 292, 288, 292, 1], ['small', 311, 266, 376, 266, 376, 292, 311, 292, 1], ['demonstration', 384, 266, 557, 266, 557, 292, 384, 292, 1], ['.pdf', 569, 266, 613, 266, 613, 292, 569, 292, 1], ['file', 621, 266, 656, 266, 656, 292, 621, 292, 1], ['-', 665, 266, 674, 266, 674, 292, 665, 292, 1], ['just', 198, 332, 244, 332, 244, 357, 198, 357, 1], ['for', 249, 332, 284, 332, 284, 357, 249, 357, 1], ['use', 291, 332, 334, 332, 334, 357, 291, 357, 1], ['in', 344, 332, 363, 332, 363, 357, 344, 357, 1], ['the', 372, 332, 410, 332, 410, 357, 372, 357, 1], ['Virtual', 420, 332, 497, 332, 497, 357, 420, 357, 1], ['Mechanics', 508, 332, 636, 332, 636, 357, 508, 357, 1], ['tutorials', 645, 332, 741, 332, 741, 357, 645, 357, 1], ['.', 746, 332, 750, 332, 750, 357, 746, 357, 1], ['More', 761, 332, 820, 332, 820, 357, 761, 357, 1], ['text', 830, 332, 874, 332, 874, 357, 830, 357, 1], ['.', 877, 332, 880, 332, 880, 357, 877, 357, 1], ['And', 890, 332, 936, 332, 936, 357, 890, 357, 1], ['more', 949, 332, 1010, 332, 1010, 357, 949, 357, 1], ['text', 198, 366, 244, 366, 244, 387, 198, 387, 1], ['.', 247, 366, 251, 366, 251, 387, 247, 387, 1], ['And', 260, 366, 309, 366, 309, 387, 260, 387, 1], ['more', 318, 366, 379, 366, 379, 387, 318, 387, 1], ['text', 388, 366, 433, 366, 433, 387, 388, 387, 1], ['.', 435, 366, 438, 366, 438, 387, 435, 387, 1], ['And', 449, 366, 495, 366, 495, 387, 449, 387, 1], ['more', 507, 366, 567, 366, 567, 387, 507, 387, 1], ['text', 576, 366, 621, 366, 621, 387, 576, 387, 1], ['.', 624, 366, 627, 366, 627, 387, 624, 387, 1], ['And', 637, 366, 684, 366, 684, 387, 637, 387, 1], ['more', 695, 366, 756, 366, 756, 387, 695, 387, 1], ['text', 764, 366, 810, 366, 810, 387, 764, 387, 1], ['.', 812, 366, 816, 366, 816, 387, 812, 387, 1], ['And', 198, 432, 248, 432, 248, 453, 198, 453, 1], ['more', 258, 432, 318, 432, 318, 453, 258, 453, 1], ['text', 327, 432, 372, 432, 372, 453, 327, 453, 1], ['.', 375, 432, 378, 432, 378, 453, 375, 453, 1], ['And', 388, 432, 435, 432, 435, 453, 388, 453, 1], ['more', 447, 432, 507, 432, 507, 453, 447, 453, 1], ['text', 516, 432, 561, 432, 561, 453, 516, 453, 1], ['.', 564, 432, 567, 432, 567, 453, 564, 453, 1], ['And', 577, 432, 624, 432, 624, 453, 577, 453, 1], ['more', 635, 432, 695, 432, 695, 453, 635, 453, 1], ['text', 704, 432, 749, 432, 749, 453, 704, 453, 1], ['.', 752, 432, 755, 432, 755, 453, 752, 453, 1], ['And', 765, 432, 811, 432, 811, 453, 765, 453, 1], ['more', 824, 432, 884, 432, 884, 453, 824, 453, 1], ['text', 893, 432, 938, 432, 938, 453, 893, 453, 1], ['.', 940, 432, 943, 432, 943, 453, 940, 453, 1], ['And', 954, 432, 1001, 432, 1001, 453, 954, 453, 1], ['more', 1011, 432, 1073, 432, 1073, 453, 1011, 453, 1], ['text', 199, 466, 245, 466, 245, 490, 199, 490, 1], ['.', 247, 466, 251, 466, 251, 490, 247, 490, 1], ['And', 260, 466, 307, 466, 307, 490, 260, 490, 1], ['more', 319, 466, 380, 466, 380, 490, 319, 490, 1], ['text', 388, 466, 432, 466, 432, 490, 388, 490, 1], ['.', 435, 466, 438, 466, 438, 490, 435, 490, 1], ['Boring', 450, 466, 526, 466, 526, 490, 450, 490, 1], [',', 531, 466, 535, 466, 535, 490, 531, 490, 1], ['zzzzz', 545, 466, 612, 466, 612, 490, 545, 490, 1], ['.', 616, 466, 620, 466, 620, 490, 616, 490, 1], ['And', 629, 466, 675, 466, 675, 490, 629, 490, 1], ['more', 688, 466, 748, 466, 748, 490, 688, 490, 1], ['text', 757, 466, 801, 466, 801, 490, 757, 490, 1], ['.', 805, 466, 807, 466, 807, 490, 805, 490, 1], ['And', 818, 466, 865, 466, 865, 490, 818, 490, 1], ['more', 877, 466, 936, 466, 936, 490, 877, 490, 1], ['text', 944, 466, 990, 466, 990, 490, 944, 490, 1], ['.', 993, 466, 997, 466, 997, 490, 993, 490, 1], ['And', 1006, 466, 1053, 466, 1053, 490, 1006, 490, 1], ['more', 200, 499, 261, 499, 261, 519, 200, 519, 1], ['text', 269, 499, 316, 499, 316, 519, 269, 519, 1], ['.', 318, 499, 322, 499, 322, 519, 318, 519, 1], ['And', 331, 499, 378, 499, 378, 519, 331, 519, 1], ['more', 390, 499, 450, 499, 450, 519, 390, 519, 1], ['text', 459, 499, 503, 499, 503, 519, 459, 519, 1], ['.', 507, 499, 510, 499, 510, 519, 507, 519, 1], ['And', 520, 499, 566, 499, 566, 519, 520, 519, 1], ['more', 578, 499, 638, 499, 638, 519, 578, 519, 1], ['text', 647, 499, 692, 499, 692, 519, 647, 519, 1], ['.', 695, 499, 698, 499, 698, 519, 695, 519, 1], ['And', 709, 499, 755, 499, 755, 519, 709, 519, 1], ['more', 766, 499, 827, 499, 827, 519, 766, 519, 1], ['text', 835, 499, 881, 499, 881, 519, 835, 519, 1], ['.', 883, 499, 886, 499, 886, 519, 883, 519, 1], ['And', 896, 499, 943, 499, 943, 519, 896, 519, 1], ['more', 955, 499, 1015, 499, 1015, 519, 955, 519, 1], ['text', 1023, 499, 1069, 499, 1069, 519, 1023, 519, 1], ['.', 1071, 499, 1075, 499, 1075, 519, 1071, 519, 1], ['And', 199, 532, 248, 532, 248, 553, 199, 553, 1], ['more', 257, 532, 318, 532, 318, 553, 257, 553, 1], ['text', 326, 532, 373, 532, 373, 553, 326, 553, 1], ['.', 375, 532, 378, 532, 378, 553, 375, 553, 1], ['And', 388, 532, 435, 532, 435, 553, 388, 553, 1], ['more', 447, 532, 507, 532, 507, 553, 447, 553, 1], ['text', 515, 532, 561, 532, 561, 553, 515, 553, 1], ['.', 563, 532, 567, 532, 567, 553, 563, 553, 1], ['And', 199, 599, 248, 599, 248, 619, 199, 619, 1], ['more', 258, 599, 318, 599, 318, 619, 258, 619, 1], ['text', 327, 599, 372, 599, 372, 619, 327, 619, 1], ['.', 375, 599, 378, 599, 378, 619, 375, 619, 1], ['And', 388, 599, 435, 599, 435, 619, 388, 619, 1], ['more', 447, 599, 507, 599, 507, 619, 447, 619, 1], ['text', 516, 599, 560, 599, 560, 619, 516, 619, 1], ['.', 564, 599, 567, 599, 567, 619, 564, 619, 1], ['And', 577, 599, 624, 599, 624, 619, 577, 619, 1], ['more', 636, 599, 696, 599, 696, 619, 636, 619, 1], ['text', 704, 599, 750, 599, 750, 619, 704, 619, 1], ['.', 752, 599, 755, 599, 755, 619, 752, 619, 1], ['And', 765, 599, 811, 599, 811, 619, 765, 619, 1], ['more', 824, 599, 883, 599, 883, 619, 824, 619, 1], ['text', 893, 599, 937, 599, 937, 619, 893, 619, 1], ['.', 941, 599, 944, 599, 944, 619, 941, 619, 1], ['And', 954, 599, 1001, 599, 1001, 619, 954, 619, 1], ['more', 1011, 599, 1073, 599, 1073, 619, 1011, 619, 1], ['text', 198, 632, 244, 632, 244, 657, 198, 657, 1], ['.', 247, 632, 251, 632, 251, 657, 247, 657, 1], ['And', 260, 632, 308, 632, 308, 657, 260, 657, 1], ['more', 318, 632, 379, 632, 379, 657, 318, 657, 1], ['text', 388, 632, 433, 632, 433, 657, 388, 657, 1], ['.', 436, 632, 439, 632, 439, 657, 436, 657, 1], ['And', 449, 632, 495, 632, 495, 657, 449, 657, 1], ['more', 507, 632, 567, 632, 567, 657, 507, 657, 1], ['text', 577, 632, 620, 632, 620, 657, 577, 657, 1], ['.', 624, 632, 627, 632, 627, 657, 624, 657, 1], ['Even', 640, 632, 698, 632, 698, 657, 640, 657, 1], ['more', 710, 632, 769, 632, 769, 657, 710, 657, 1], ['.', 774, 632, 778, 632, 778, 657, 774, 657, 1], ['Continued', 788, 632, 910, 632, 910, 657, 788, 657, 1], ['on', 922, 632, 949, 632, 949, 657, 922, 657, 1], ['page', 960, 632, 1020, 632, 1020, 657, 960, 657, 1], ['2', 1029, 632, 1043, 632, 1043, 657, 1029, 657, 1], ['Simple', 196, 751, 418, 747, 419, 815, 197, 819, 1], ['PDF', 445, 747, 587, 744, 588, 811, 446, 814, 1], ['File', 613, 743, 734, 741, 735, 809, 614, 811, 1], ['2', 751, 741, 797, 740, 798, 807, 752, 808, 1], ['...', 214, 882, 236, 882, 236, 907, 214, 907, 1], ['continued', 237, 882, 355, 882, 355, 907, 237, 907, 1], ['from', 364, 882, 418, 882, 418, 907, 364, 907, 1], ['page', 429, 882, 488, 882, 488, 907, 429, 907, 1], ['1.', 500, 882, 519, 882, 519, 907, 500, 907, 1], ['Yet', 529, 882, 570, 882, 570, 907, 529, 907, 1], ['more', 580, 882, 640, 882, 640, 907, 580, 907, 1], ['text', 649, 882, 694, 882, 694, 907, 649, 907, 1], ['.', 697, 882, 701, 882, 701, 907, 697, 907, 1], ['And', 709, 882, 757, 882, 757, 907, 709, 907, 1], ['more', 768, 882, 828, 882, 828, 907, 768, 907, 1], ['text', 837, 882, 882, 882, 882, 907, 837, 907, 1], ['.', 885, 882, 889, 882, 889, 907, 885, 907, 1], ['And', 898, 882, 945, 882, 945, 907, 898, 907, 1], ['more', 956, 882, 1017, 882, 1017, 907, 956, 907, 1], ['text', 1025, 882, 1071, 882, 1071, 907, 1025, 907, 1], ['.', 1072, 882, 1078, 882, 1078, 907, 1072, 907, 1], ['And', 214, 915, 262, 915, 262, 936, 214, 936, 1], ['more', 272, 915, 332, 915, 332, 936, 272, 936, 1], ['text', 340, 915, 386, 915, 386, 936, 340, 936, 1], ['.', 390, 915, 393, 915, 393, 936, 390, 936, 1], ['And', 402, 915, 449, 915, 449, 936, 402, 936, 1], ['more', 461, 915, 521, 915, 521, 936, 461, 936, 1], ['text', 530, 915, 575, 915, 575, 936, 530, 936, 1], ['.', 578, 915, 581, 915, 581, 936, 578, 936, 1], ['And', 591, 915, 638, 915, 638, 936, 591, 936, 1], ['more', 649, 915, 710, 915, 710, 936, 649, 936, 1], ['text', 718, 915, 763, 915, 763, 936, 718, 936, 1], ['.', 766, 915, 769, 915, 769, 936, 766, 936, 1], ['And', 779, 915, 825, 915, 825, 936, 779, 936, 1], ['more', 838, 915, 898, 915, 898, 936, 838, 936, 1], ['text', 907, 915, 952, 915, 952, 936, 907, 936, 1], ['.', 955, 915, 957, 915, 957, 936, 955, 936, 1], ['And', 968, 915, 1014, 915, 1014, 936, 968, 936, 1], ['more', 1025, 915, 1088, 915, 1088, 936, 1025, 936, 1], ['text', 212, 947, 259, 947, 259, 974, 212, 974, 1], ['.', 261, 947, 266, 947, 266, 974, 261, 974, 1], ['Oh', 275, 947, 309, 947, 309, 974, 275, 974, 1], [',', 313, 947, 318, 947, 318, 974, 313, 974, 1], ['how', 327, 947, 375, 947, 375, 974, 327, 974, 1], ['boring', 386, 947, 460, 947, 460, 974, 386, 974, 1], ['typing', 470, 947, 542, 947, 542, 974, 470, 974, 1], ['this', 551, 947, 594, 947, 594, 974, 551, 974, 1], ['stuff', 604, 947, 655, 947, 655, 974, 604, 974, 1], ['.', 658, 947, 660, 947, 660, 974, 658, 974, 1], ['But', 673, 947, 712, 947, 712, 974, 673, 974, 1], ['not', 722, 947, 758, 947, 758, 974, 722, 974, 1], ['as', 768, 947, 794, 947, 794, 974, 768, 974, 1], ['boring', 805, 947, 879, 947, 879, 974, 805, 974, 1], ['as', 890, 947, 917, 947, 917, 974, 890, 974, 1], ['watching', 926, 947, 1035, 947, 1035, 974, 926, 974, 1], ['paint', 214, 981, 275, 981, 275, 1005, 214, 1005, 1], ['dry', 282, 981, 320, 981, 320, 1005, 282, 1005, 1], ['.', 322, 981, 328, 981, 328, 1005, 322, 1005, 1], ['And', 335, 981, 383, 981, 383, 1005, 335, 1005, 1], ['more', 395, 981, 454, 981, 454, 1005, 395, 1005, 1], ['text', 463, 981, 508, 981, 508, 1005, 463, 1005, 1], ['.', 511, 981, 515, 981, 515, 1005, 511, 1005, 1], ['And', 524, 981, 571, 981, 571, 1005, 524, 1005, 1], ['more', 583, 981, 643, 981, 643, 1005, 583, 1005, 1], ['text', 652, 981, 696, 981, 696, 1005, 652, 1005, 1], ['.', 700, 981, 704, 981, 704, 1005, 700, 1005, 1], ['And', 713, 981, 760, 981, 760, 1005, 713, 1005, 1], ['more', 772, 981, 831, 981, 831, 1005, 772, 1005, 1], ['text', 840, 981, 885, 981, 885, 1005, 840, 1005, 1], ['.', 888, 981, 891, 981, 891, 1005, 888, 1005, 1], ['And', 901, 981, 948, 981, 948, 1005, 901, 1005, 1], ['more', 960, 981, 1020, 981, 1020, 1005, 960, 1005, 1], ['text', 1028, 981, 1074, 981, 1074, 1005, 1028, 1005, 1], ['.', 1075, 981, 1081, 981, 1081, 1005, 1075, 1005, 1], ['Boring', 215, 1014, 292, 1014, 292, 1040, 215, 1040, 1], ['.', 296, 1014, 302, 1014, 302, 1040, 296, 1040, 1], ['More', 318, 1014, 380, 1014, 380, 1040, 318, 1040, 1], [',', 381, 1014, 386, 1014, 386, 1040, 381, 1040, 1], ['a', 396, 1014, 409, 1014, 409, 1040, 396, 1040, 1], ['little', 420, 1014, 467, 1014, 467, 1040, 420, 1040, 1], ['more', 478, 1014, 538, 1014, 538, 1040, 478, 1040, 1], ['text', 547, 1014, 592, 1014, 592, 1040, 547, 1040, 1], ['.', 595, 1014, 598, 1014, 598, 1040, 595, 1040, 1], ['The', 608, 1014, 653, 1014, 653, 1040, 608, 1040, 1], ['end', 664, 1014, 708, 1014, 708, 1040, 664, 1040, 1], [',', 711, 1014, 715, 1014, 715, 1040, 711, 1040, 1], ['and', 725, 1014, 769, 1014, 769, 1040, 725, 1040, 1], ['just', 777, 1014, 822, 1014, 822, 1040, 777, 1040, 1], ['as', 830, 1014, 858, 1014, 858, 1040, 830, 1040, 1], ['well', 866, 1014, 915, 1014, 915, 1040, 866, 1040, 1], ['.', 916, 1014, 921, 1014, 921, 1040, 916, 1040, 1]]


@pytest.mark.depends(name=["test_read_png_uppercase", "test_entries_png_uppercase"])
def test_lower_case_png(bot: BotCloudVisionPlugin):
    bot.to_lower_case()
    assert bot._to_lowercase
    assert not bot._to_uppercase


@pytest.mark.depends(name="test_lower_case_png")
def test_read_png_lowercase(bot: BotCloudVisionPlugin):
    bot.read(filepath=PATH_PNG)
    assert bot.full_text() == '\na simple pdf file\nthis is a small demonstration .pdf file -\njust for use in the virtual mechanics tutorials. more text. and more\ntext. and more text. and more text. and more text.\nand more text. and more text. and more text. and more text. and more\ntext. and more text. boring, zzzzz. and more text. and more text. and\nmore text. and more text. and more text. and more text. and more text.\nand more text. and more text.\nand more text. and more text. and more text. and more text. and more\ntext. and more text. and more text. even more. continued on page 2\nsimple pdf file 2\n...continued from page 1. yet more text. and more text. and more text.\nand more text. and more text. and more text. and more text. and more\ntext. oh, how boring typing this stuff. but not as boring as watching\npaint dry. and more text. and more text. and more text. and more text.\nboring. more, a little more text. the end, and just as well.'


@pytest.mark.depends(name="test_lower_case_png")
def test_entries_png_lowercase(bot: BotCloudVisionPlugin):
    bot.read(filepath=PATH_PNG)
    assert bot.entries() == [['A', 178, 140, 225, 139, 226, 204, 179, 205, 1], ['Simple', 252, 138, 474, 134, 475, 199, 253, 203, 1], ['PDF', 504, 134, 645, 131, 646, 196, 505, 199, 1], ['File', 675, 130, 788, 128, 789, 194, 676, 196, 1], ['This', 200, 266, 252, 266, 252, 292, 200, 292, 1], ['is', 261, 266, 279, 266, 279, 292, 261, 292, 1], ['a', 288, 266, 303, 266, 303, 292, 288, 292, 1], ['small', 311, 266, 376, 266, 376, 292, 311, 292, 1], ['demonstration', 384, 266, 557, 266, 557, 292, 384, 292, 1], ['.pdf', 569, 266, 613, 266, 613, 292, 569, 292, 1], ['file', 621, 266, 656, 266, 656, 292, 621, 292, 1], ['-', 665, 266, 674, 266, 674, 292, 665, 292, 1], ['just', 198, 332, 244, 332, 244, 357, 198, 357, 1], ['for', 249, 332, 284, 332, 284, 357, 249, 357, 1], ['use', 291, 332, 334, 332, 334, 357, 291, 357, 1], ['in', 344, 332, 363, 332, 363, 357, 344, 357, 1], ['the', 372, 332, 410, 332, 410, 357, 372, 357, 1], ['Virtual', 420, 332, 497, 332, 497, 357, 420, 357, 1], ['Mechanics', 508, 332, 636, 332, 636, 357, 508, 357, 1], ['tutorials', 645, 332, 741, 332, 741, 357, 645, 357, 1], ['.', 746, 332, 750, 332, 750, 357, 746, 357, 1], ['More', 761, 332, 820, 332, 820, 357, 761, 357, 1], ['text', 830, 332, 874, 332, 874, 357, 830, 357, 1], ['.', 877, 332, 880, 332, 880, 357, 877, 357, 1], ['And', 890, 332, 936, 332, 936, 357, 890, 357, 1], ['more', 949, 332, 1010, 332, 1010, 357, 949, 357, 1], ['text', 198, 366, 244, 366, 244, 387, 198, 387, 1], ['.', 247, 366, 251, 366, 251, 387, 247, 387, 1], ['And', 260, 366, 309, 366, 309, 387, 260, 387, 1], ['more', 318, 366, 379, 366, 379, 387, 318, 387, 1], ['text', 388, 366, 433, 366, 433, 387, 388, 387, 1], ['.', 435, 366, 438, 366, 438, 387, 435, 387, 1], ['And', 449, 366, 495, 366, 495, 387, 449, 387, 1], ['more', 507, 366, 567, 366, 567, 387, 507, 387, 1], ['text', 576, 366, 621, 366, 621, 387, 576, 387, 1], ['.', 624, 366, 627, 366, 627, 387, 624, 387, 1], ['And', 637, 366, 684, 366, 684, 387, 637, 387, 1], ['more', 695, 366, 756, 366, 756, 387, 695, 387, 1], ['text', 764, 366, 810, 366, 810, 387, 764, 387, 1], ['.', 812, 366, 816, 366, 816, 387, 812, 387, 1], ['And', 198, 432, 248, 432, 248, 453, 198, 453, 1], ['more', 258, 432, 318, 432, 318, 453, 258, 453, 1], ['text', 327, 432, 372, 432, 372, 453, 327, 453, 1], ['.', 375, 432, 378, 432, 378, 453, 375, 453, 1], ['And', 388, 432, 435, 432, 435, 453, 388, 453, 1], ['more', 447, 432, 507, 432, 507, 453, 447, 453, 1], ['text', 516, 432, 561, 432, 561, 453, 516, 453, 1], ['.', 564, 432, 567, 432, 567, 453, 564, 453, 1], ['And', 577, 432, 624, 432, 624, 453, 577, 453, 1], ['more', 635, 432, 695, 432, 695, 453, 635, 453, 1], ['text', 704, 432, 749, 432, 749, 453, 704, 453, 1], ['.', 752, 432, 755, 432, 755, 453, 752, 453, 1], ['And', 765, 432, 811, 432, 811, 453, 765, 453, 1], ['more', 824, 432, 884, 432, 884, 453, 824, 453, 1], ['text', 893, 432, 938, 432, 938, 453, 893, 453, 1], ['.', 940, 432, 943, 432, 943, 453, 940, 453, 1], ['And', 954, 432, 1001, 432, 1001, 453, 954, 453, 1], ['more', 1011, 432, 1073, 432, 1073, 453, 1011, 453, 1], ['text', 199, 466, 245, 466, 245, 490, 199, 490, 1], ['.', 247, 466, 251, 466, 251, 490, 247, 490, 1], ['And', 260, 466, 307, 466, 307, 490, 260, 490, 1], ['more', 319, 466, 380, 466, 380, 490, 319, 490, 1], ['text', 388, 466, 432, 466, 432, 490, 388, 490, 1], ['.', 435, 466, 438, 466, 438, 490, 435, 490, 1], ['Boring', 450, 466, 526, 466, 526, 490, 450, 490, 1], [',', 531, 466, 535, 466, 535, 490, 531, 490, 1], ['zzzzz', 545, 466, 612, 466, 612, 490, 545, 490, 1], ['.', 616, 466, 620, 466, 620, 490, 616, 490, 1], ['And', 629, 466, 675, 466, 675, 490, 629, 490, 1], ['more', 688, 466, 748, 466, 748, 490, 688, 490, 1], ['text', 757, 466, 801, 466, 801, 490, 757, 490, 1], ['.', 805, 466, 807, 466, 807, 490, 805, 490, 1], ['And', 818, 466, 865, 466, 865, 490, 818, 490, 1], ['more', 877, 466, 936, 466, 936, 490, 877, 490, 1], ['text', 944, 466, 990, 466, 990, 490, 944, 490, 1], ['.', 993, 466, 997, 466, 997, 490, 993, 490, 1], ['And', 1006, 466, 1053, 466, 1053, 490, 1006, 490, 1], ['more', 200, 499, 261, 499, 261, 519, 200, 519, 1], ['text', 269, 499, 316, 499, 316, 519, 269, 519, 1], ['.', 318, 499, 322, 499, 322, 519, 318, 519, 1], ['And', 331, 499, 378, 499, 378, 519, 331, 519, 1], ['more', 390, 499, 450, 499, 450, 519, 390, 519, 1], ['text', 459, 499, 503, 499, 503, 519, 459, 519, 1], ['.', 507, 499, 510, 499, 510, 519, 507, 519, 1], ['And', 520, 499, 566, 499, 566, 519, 520, 519, 1], ['more', 578, 499, 638, 499, 638, 519, 578, 519, 1], ['text', 647, 499, 692, 499, 692, 519, 647, 519, 1], ['.', 695, 499, 698, 499, 698, 519, 695, 519, 1], ['And', 709, 499, 755, 499, 755, 519, 709, 519, 1], ['more', 766, 499, 827, 499, 827, 519, 766, 519, 1], ['text', 835, 499, 881, 499, 881, 519, 835, 519, 1], ['.', 883, 499, 886, 499, 886, 519, 883, 519, 1], ['And', 896, 499, 943, 499, 943, 519, 896, 519, 1], ['more', 955, 499, 1015, 499, 1015, 519, 955, 519, 1], ['text', 1023, 499, 1069, 499, 1069, 519, 1023, 519, 1], ['.', 1071, 499, 1075, 499, 1075, 519, 1071, 519, 1], ['And', 199, 532, 248, 532, 248, 553, 199, 553, 1], ['more', 257, 532, 318, 532, 318, 553, 257, 553, 1], ['text', 326, 532, 373, 532, 373, 553, 326, 553, 1], ['.', 375, 532, 378, 532, 378, 553, 375, 553, 1], ['And', 388, 532, 435, 532, 435, 553, 388, 553, 1], ['more', 447, 532, 507, 532, 507, 553, 447, 553, 1], ['text', 515, 532, 561, 532, 561, 553, 515, 553, 1], ['.', 563, 532, 567, 532, 567, 553, 563, 553, 1], ['And', 199, 599, 248, 599, 248, 619, 199, 619, 1], ['more', 258, 599, 318, 599, 318, 619, 258, 619, 1], ['text', 327, 599, 372, 599, 372, 619, 327, 619, 1], ['.', 375, 599, 378, 599, 378, 619, 375, 619, 1], ['And', 388, 599, 435, 599, 435, 619, 388, 619, 1], ['more', 447, 599, 507, 599, 507, 619, 447, 619, 1], ['text', 516, 599, 560, 599, 560, 619, 516, 619, 1], ['.', 564, 599, 567, 599, 567, 619, 564, 619, 1], ['And', 577, 599, 624, 599, 624, 619, 577, 619, 1], ['more', 636, 599, 696, 599, 696, 619, 636, 619, 1], ['text', 704, 599, 750, 599, 750, 619, 704, 619, 1], ['.', 752, 599, 755, 599, 755, 619, 752, 619, 1], ['And', 765, 599, 811, 599, 811, 619, 765, 619, 1], ['more', 824, 599, 883, 599, 883, 619, 824, 619, 1], ['text', 893, 599, 937, 599, 937, 619, 893, 619, 1], ['.', 941, 599, 944, 599, 944, 619, 941, 619, 1], ['And', 954, 599, 1001, 599, 1001, 619, 954, 619, 1], ['more', 1011, 599, 1073, 599, 1073, 619, 1011, 619, 1], ['text', 198, 632, 244, 632, 244, 657, 198, 657, 1], ['.', 247, 632, 251, 632, 251, 657, 247, 657, 1], ['And', 260, 632, 308, 632, 308, 657, 260, 657, 1], ['more', 318, 632, 379, 632, 379, 657, 318, 657, 1], ['text', 388, 632, 433, 632, 433, 657, 388, 657, 1], ['.', 436, 632, 439, 632, 439, 657, 436, 657, 1], ['And', 449, 632, 495, 632, 495, 657, 449, 657, 1], ['more', 507, 632, 567, 632, 567, 657, 507, 657, 1], ['text', 577, 632, 620, 632, 620, 657, 577, 657, 1], ['.', 624, 632, 627, 632, 627, 657, 624, 657, 1], ['Even', 640, 632, 698, 632, 698, 657, 640, 657, 1], ['more', 710, 632, 769, 632, 769, 657, 710, 657, 1], ['.', 774, 632, 778, 632, 778, 657, 774, 657, 1], ['Continued', 788, 632, 910, 632, 910, 657, 788, 657, 1], ['on', 922, 632, 949, 632, 949, 657, 922, 657, 1], ['page', 960, 632, 1020, 632, 1020, 657, 960, 657, 1], ['2', 1029, 632, 1043, 632, 1043, 657, 1029, 657, 1], ['Simple', 196, 751, 418, 747, 419, 815, 197, 819, 1], ['PDF', 445, 747, 587, 744, 588, 811, 446, 814, 1], ['File', 613, 743, 734, 741, 735, 809, 614, 811, 1], ['2', 751, 741, 797, 740, 798, 807, 752, 808, 1], ['...', 214, 882, 236, 882, 236, 907, 214, 907, 1], ['continued', 237, 882, 355, 882, 355, 907, 237, 907, 1], ['from', 364, 882, 418, 882, 418, 907, 364, 907, 1], ['page', 429, 882, 488, 882, 488, 907, 429, 907, 1], ['1.', 500, 882, 519, 882, 519, 907, 500, 907, 1], ['Yet', 529, 882, 570, 882, 570, 907, 529, 907, 1], ['more', 580, 882, 640, 882, 640, 907, 580, 907, 1], ['text', 649, 882, 694, 882, 694, 907, 649, 907, 1], ['.', 697, 882, 701, 882, 701, 907, 697, 907, 1], ['And', 709, 882, 757, 882, 757, 907, 709, 907, 1], ['more', 768, 882, 828, 882, 828, 907, 768, 907, 1], ['text', 837, 882, 882, 882, 882, 907, 837, 907, 1], ['.', 885, 882, 889, 882, 889, 907, 885, 907, 1], ['And', 898, 882, 945, 882, 945, 907, 898, 907, 1], ['more', 956, 882, 1017, 882, 1017, 907, 956, 907, 1], ['text', 1025, 882, 1071, 882, 1071, 907, 1025, 907, 1], ['.', 1072, 882, 1078, 882, 1078, 907, 1072, 907, 1], ['And', 214, 915, 262, 915, 262, 936, 214, 936, 1], ['more', 272, 915, 332, 915, 332, 936, 272, 936, 1], ['text', 340, 915, 386, 915, 386, 936, 340, 936, 1], ['.', 390, 915, 393, 915, 393, 936, 390, 936, 1], ['And', 402, 915, 449, 915, 449, 936, 402, 936, 1], ['more', 461, 915, 521, 915, 521, 936, 461, 936, 1], ['text', 530, 915, 575, 915, 575, 936, 530, 936, 1], ['.', 578, 915, 581, 915, 581, 936, 578, 936, 1], ['And', 591, 915, 638, 915, 638, 936, 591, 936, 1], ['more', 649, 915, 710, 915, 710, 936, 649, 936, 1], ['text', 718, 915, 763, 915, 763, 936, 718, 936, 1], ['.', 766, 915, 769, 915, 769, 936, 766, 936, 1], ['And', 779, 915, 825, 915, 825, 936, 779, 936, 1], ['more', 838, 915, 898, 915, 898, 936, 838, 936, 1], ['text', 907, 915, 952, 915, 952, 936, 907, 936, 1], ['.', 955, 915, 957, 915, 957, 936, 955, 936, 1], ['And', 968, 915, 1014, 915, 1014, 936, 968, 936, 1], ['more', 1025, 915, 1088, 915, 1088, 936, 1025, 936, 1], ['text', 212, 947, 259, 947, 259, 974, 212, 974, 1], ['.', 261, 947, 266, 947, 266, 974, 261, 974, 1], ['Oh', 275, 947, 309, 947, 309, 974, 275, 974, 1], [',', 313, 947, 318, 947, 318, 974, 313, 974, 1], ['how', 327, 947, 375, 947, 375, 974, 327, 974, 1], ['boring', 386, 947, 460, 947, 460, 974, 386, 974, 1], ['typing', 470, 947, 542, 947, 542, 974, 470, 974, 1], ['this', 551, 947, 594, 947, 594, 974, 551, 974, 1], ['stuff', 604, 947, 655, 947, 655, 974, 604, 974, 1], ['.', 658, 947, 660, 947, 660, 974, 658, 974, 1], ['But', 673, 947, 712, 947, 712, 974, 673, 974, 1], ['not', 722, 947, 758, 947, 758, 974, 722, 974, 1], ['as', 768, 947, 794, 947, 794, 974, 768, 974, 1], ['boring', 805, 947, 879, 947, 879, 974, 805, 974, 1], ['as', 890, 947, 917, 947, 917, 974, 890, 974, 1], ['watching', 926, 947, 1035, 947, 1035, 974, 926, 974, 1], ['paint', 214, 981, 275, 981, 275, 1005, 214, 1005, 1], ['dry', 282, 981, 320, 981, 320, 1005, 282, 1005, 1], ['.', 322, 981, 328, 981, 328, 1005, 322, 1005, 1], ['And', 335, 981, 383, 981, 383, 1005, 335, 1005, 1], ['more', 395, 981, 454, 981, 454, 1005, 395, 1005, 1], ['text', 463, 981, 508, 981, 508, 1005, 463, 1005, 1], ['.', 511, 981, 515, 981, 515, 1005, 511, 1005, 1], ['And', 524, 981, 571, 981, 571, 1005, 524, 1005, 1], ['more', 583, 981, 643, 981, 643, 1005, 583, 1005, 1], ['text', 652, 981, 696, 981, 696, 1005, 652, 1005, 1], ['.', 700, 981, 704, 981, 704, 1005, 700, 1005, 1], ['And', 713, 981, 760, 981, 760, 1005, 713, 1005, 1], ['more', 772, 981, 831, 981, 831, 1005, 772, 1005, 1], ['text', 840, 981, 885, 981, 885, 1005, 840, 1005, 1], ['.', 888, 981, 891, 981, 891, 1005, 888, 1005, 1], ['And', 901, 981, 948, 981, 948, 1005, 901, 1005, 1], ['more', 960, 981, 1020, 981, 1020, 1005, 960, 1005, 1], ['text', 1028, 981, 1074, 981, 1074, 1005, 1028, 1005, 1], ['.', 1075, 981, 1081, 981, 1081, 1005, 1075, 1005, 1], ['Boring', 215, 1014, 292, 1014, 292, 1040, 215, 1040, 1], ['.', 296, 1014, 302, 1014, 302, 1040, 296, 1040, 1], ['More', 318, 1014, 380, 1014, 380, 1040, 318, 1040, 1], [',', 381, 1014, 386, 1014, 386, 1040, 381, 1040, 1], ['a', 396, 1014, 409, 1014, 409, 1040, 396, 1040, 1], ['little', 420, 1014, 467, 1014, 467, 1040, 420, 1040, 1], ['more', 478, 1014, 538, 1014, 538, 1040, 478, 1040, 1], ['text', 547, 1014, 592, 1014, 592, 1040, 547, 1040, 1], ['.', 595, 1014, 598, 1014, 598, 1040, 595, 1040, 1], ['The', 608, 1014, 653, 1014, 653, 1040, 608, 1040, 1], ['end', 664, 1014, 708, 1014, 708, 1040, 664, 1040, 1], [',', 711, 1014, 715, 1014, 715, 1040, 711, 1040, 1], ['and', 725, 1014, 769, 1014, 769, 1040, 725, 1040, 1], ['just', 777, 1014, 822, 1014, 822, 1040, 777, 1040, 1], ['as', 830, 1014, 858, 1014, 858, 1040, 830, 1040, 1], ['well', 866, 1014, 915, 1014, 915, 1040, 866, 1040, 1], ['.', 916, 1014, 921, 1014, 921, 1040, 916, 1040, 1]]


def test_read_pdf(bot: BotCloudVisionPlugin):
    bot.reset_case()
    bot.read(filepath=PATH_PDF)
    full_text = bot.full_text()
    assert full_text == '\nA Simple PDF File\nThis is a small demonstration .pdf file-\njust for use in the Virtual Mechanics tutorials. More text. And more\ntext. And more text. And more text. And more text.\nAnd more text. And more text. And more text. And more text. And more\ntext. And more text. Boring, zzzzz. And more text. And more text. And\nmore text. And more text. And more text. And more text. And more text.\nAnd more text. And more text.\nAnd more text. And more text. And more text. And more text. And more\ntext. And more text. And more text. Even more. Continued on page 2...\nSimple PDF File 2\n...continued from page 1. Yet more text. And more text. And more text.\nAnd more text. And more text. And more text. And more text. And more\ntext.Oh, how boring typing this stuff. But not as boring as watching\npaint dry. And more text. And more text. And more text. And more text.\nBoring. More, a little more text. The end, and just as well.'


@pytest.mark.depends(name="test_read_pdf")
def test_render_rate_pdf(bot: BotCloudVisionPlugin):
    assert bot.render_rate() == 72


@pytest.mark.depends(name="test_read_pdf")
def test_threshold_pdf(bot: BotCloudVisionPlugin):
    assert bot.threshold() is None


@pytest.mark.depends(name="test_read_pdf")
def test_entries_pdf(bot: BotCloudVisionPlugin):
    entries = bot.entries()
    assert entries == [['A', 64, 50, 82, 50, 82, 74, 64, 74, 1], ['Simple', 90, 49, 170, 48, 170, 72, 90, 73, 1], ['PDF', 180, 47, 231, 46, 231, 71, 180, 72, 1], ['File', 241, 46, 283, 45, 283, 70, 241, 71, 1], ['This', 71, 95, 90, 95, 90, 105, 71, 105, 1], ['is', 93, 95, 100, 95, 100, 105, 93, 105, 1], ['a', 103, 95, 109, 95, 109, 105, 103, 105, 1], ['small', 111, 95, 135, 95, 135, 105, 111, 105, 1], ['demonstration', 137, 95, 199, 95, 199, 105, 137, 105, 1], ['.pdf', 204, 95, 220, 95, 220, 105, 204, 105, 1], ['file', 222, 95, 235, 95, 235, 105, 222, 105, 1], ['just', 70, 119, 88, 119, 88, 128, 70, 128, 1], ['for', 89, 119, 102, 119, 102, 128, 89, 128, 1], ['use', 104, 119, 121, 119, 121, 128, 104, 128, 1], ['in', 123, 119, 130, 119, 130, 128, 123, 128, 1], ['the', 133, 119, 148, 119, 148, 128, 133, 128, 1], ['Virtual', 150, 119, 178, 119, 178, 128, 150, 128, 1], ['Mechanics', 182, 119, 229, 119, 229, 128, 182, 128, 1], ['tutorials', 231, 119, 266, 119, 266, 128, 231, 128, 1], ['.', 267, 119, 269, 119, 269, 128, 267, 128, 1], ['More', 273, 119, 294, 119, 294, 128, 273, 128, 1], ['text', 298, 119, 314, 119, 314, 128, 298, 128, 1], ['.', 315, 119, 317, 119, 317, 128, 315, 128, 1], ['And', 319, 119, 337, 119, 337, 128, 319, 128, 1], ['more', 341, 119, 362, 119, 362, 128, 341, 128, 1], ['text', 71, 131, 88, 131, 88, 140, 71, 140, 1], ['.', 88, 131, 90, 131, 90, 140, 88, 140, 1], ['And', 92, 131, 110, 131, 110, 140, 92, 140, 1], ['more', 114, 131, 136, 131, 136, 140, 114, 140, 1], ['text', 139, 131, 156, 131, 156, 140, 139, 140, 1], ['.', 156, 131, 158, 131, 158, 140, 156, 140, 1], ['And', 160, 131, 179, 131, 179, 140, 160, 140, 1], ['more', 181, 131, 203, 131, 203, 140, 181, 140, 1], ['text', 206, 131, 223, 131, 223, 140, 206, 140, 1], ['.', 223, 131, 225, 131, 225, 140, 223, 140, 1], ['And', 228, 131, 245, 131, 245, 140, 228, 140, 1], ['more', 249, 131, 272, 131, 272, 140, 249, 140, 1], ['text', 274, 131, 291, 131, 291, 140, 274, 140, 1], ['.', 290, 131, 294, 131, 294, 140, 290, 140, 1], ['And', 71, 155, 89, 155, 89, 163, 71, 163, 1], ['more', 92, 155, 114, 155, 114, 163, 92, 163, 1], ['text', 117, 155, 133, 155, 133, 163, 117, 163, 1], ['.', 134, 155, 136, 155, 136, 163, 134, 163, 1], ['And', 139, 155, 156, 155, 156, 163, 139, 163, 1], ['more', 160, 155, 182, 155, 182, 163, 160, 163, 1], ['text', 185, 155, 201, 155, 201, 163, 185, 163, 1], ['.', 202, 155, 204, 155, 204, 163, 202, 163, 1], ['And', 206, 155, 224, 155, 224, 163, 206, 163, 1], ['more', 228, 155, 250, 155, 250, 163, 228, 163, 1], ['text', 253, 155, 269, 155, 269, 163, 253, 163, 1], ['.', 270, 155, 272, 155, 272, 163, 270, 163, 1], ['And', 275, 155, 292, 155, 292, 163, 275, 163, 1], ['more', 296, 155, 317, 155, 317, 163, 296, 163, 1], ['text', 321, 155, 337, 155, 337, 163, 321, 163, 1], ['.', 338, 155, 340, 155, 340, 163, 338, 163, 1], ['And', 342, 155, 360, 155, 360, 163, 342, 163, 1], ['more', 364, 155, 385, 155, 385, 163, 364, 163, 1], ['text', 71, 167, 87, 167, 87, 176, 71, 176, 1], ['.', 88, 167, 90, 167, 90, 176, 88, 176, 1], ['And', 93, 167, 110, 167, 110, 176, 93, 176, 1], ['more', 114, 167, 135, 167, 135, 176, 114, 176, 1], ['text', 139, 167, 156, 167, 156, 176, 139, 176, 1], ['.', 155, 167, 157, 167, 157, 176, 155, 176, 1], ['Boring', 161, 167, 189, 167, 189, 176, 161, 176, 1], [',', 191, 167, 192, 167, 192, 176, 191, 176, 1], ['zzzzz', 195, 167, 220, 167, 220, 176, 195, 176, 1], ['.', 220, 167, 222, 167, 222, 176, 220, 176, 1], ['And', 226, 167, 243, 167, 243, 176, 226, 176, 1], ['more', 246, 167, 269, 167, 269, 176, 246, 176, 1], ['text', 272, 167, 288, 167, 288, 176, 272, 176, 1], ['.', 288, 167, 290, 167, 290, 176, 288, 176, 1], ['And', 293, 167, 310, 167, 310, 176, 293, 176, 1], ['more', 315, 167, 336, 167, 336, 176, 315, 176, 1], ['text', 340, 167, 355, 167, 355, 176, 340, 176, 1], ['.', 356, 167, 359, 167, 359, 176, 356, 176, 1], ['And', 361, 167, 379, 167, 379, 176, 361, 176, 1], ['more', 71, 180, 93, 180, 93, 188, 71, 188, 1], ['text', 96, 180, 114, 180, 114, 188, 96, 188, 1], ['.', 113, 180, 115, 180, 115, 188, 113, 188, 1], ['And', 118, 180, 136, 180, 136, 188, 118, 188, 1], ['more', 139, 180, 162, 180, 162, 188, 139, 188, 1], ['text', 164, 180, 181, 180, 181, 188, 164, 188, 1], ['.', 182, 180, 184, 180, 184, 188, 182, 188, 1], ['And', 186, 180, 203, 180, 203, 188, 186, 188, 1], ['more', 207, 180, 229, 180, 229, 188, 207, 188, 1], ['text', 232, 180, 248, 180, 248, 188, 232, 188, 1], ['.', 249, 180, 251, 180, 251, 188, 249, 188, 1], ['And', 254, 180, 271, 180, 271, 188, 254, 188, 1], ['more', 275, 180, 297, 180, 297, 188, 275, 188, 1], ['text', 300, 180, 316, 180, 316, 188, 300, 188, 1], ['.', 317, 180, 319, 180, 319, 188, 317, 188, 1], ['And', 322, 180, 339, 180, 339, 188, 322, 188, 1], ['more', 343, 180, 365, 180, 365, 188, 343, 188, 1], ['text', 368, 180, 385, 180, 385, 188, 368, 188, 1], ['.', 384, 180, 386, 180, 386, 188, 384, 188, 1], ['And', 71, 191, 89, 191, 89, 200, 71, 200, 1], ['more', 92, 191, 114, 191, 114, 200, 92, 200, 1], ['text', 117, 191, 134, 191, 134, 200, 117, 200, 1], ['.', 134, 191, 136, 191, 136, 200, 134, 200, 1], ['And', 139, 191, 156, 191, 156, 200, 139, 200, 1], ['more', 160, 191, 182, 191, 182, 200, 160, 200, 1], ['text', 184, 191, 202, 191, 202, 200, 184, 200, 1], ['.', 202, 191, 205, 191, 205, 200, 202, 200, 1], ['And', 71, 214, 89, 214, 89, 223, 71, 223, 1], ['more', 92, 214, 114, 214, 114, 223, 92, 223, 1], ['text', 117, 214, 134, 214, 134, 223, 117, 223, 1], ['.', 134, 214, 136, 214, 136, 223, 134, 223, 1], ['And', 139, 214, 156, 214, 156, 223, 139, 223, 1], ['more', 160, 214, 181, 214, 181, 223, 160, 223, 1], ['text', 185, 214, 201, 214, 201, 223, 185, 223, 1], ['.', 202, 214, 204, 214, 204, 223, 202, 223, 1], ['And', 207, 214, 224, 214, 224, 223, 207, 223, 1], ['more', 228, 214, 249, 214, 249, 223, 228, 223, 1], ['text', 253, 214, 269, 214, 269, 223, 253, 223, 1], ['.', 269, 214, 271, 214, 271, 223, 269, 223, 1], ['And', 275, 214, 291, 214, 291, 223, 275, 223, 1], ['more', 296, 214, 317, 214, 317, 223, 296, 223, 1], ['text', 321, 214, 337, 214, 337, 223, 321, 223, 1], ['.', 337, 214, 339, 214, 339, 223, 337, 223, 1], ['And', 342, 214, 360, 214, 360, 223, 342, 223, 1], ['more', 364, 214, 386, 214, 386, 223, 364, 223, 1], ['text', 71, 227, 88, 227, 88, 237, 71, 237, 1], ['.', 88, 227, 90, 227, 90, 237, 88, 237, 1], ['And', 93, 227, 110, 227, 110, 237, 93, 237, 1], ['more', 113, 227, 136, 227, 136, 237, 113, 237, 1], ['text', 139, 227, 155, 227, 155, 237, 139, 237, 1], ['.', 155, 227, 157, 227, 157, 237, 155, 237, 1], ['And', 161, 227, 178, 227, 178, 237, 161, 237, 1], ['more', 182, 227, 203, 227, 203, 237, 182, 237, 1], ['text', 206, 227, 223, 227, 223, 237, 206, 237, 1], ['.', 224, 227, 226, 227, 226, 237, 224, 237, 1], ['Even', 229, 227, 250, 227, 250, 237, 229, 237, 1], ['more', 254, 227, 276, 227, 276, 237, 254, 237, 1], ['.', 278, 227, 280, 227, 280, 237, 278, 237, 1], ['Continued', 283, 227, 327, 227, 327, 237, 283, 237, 1], ['on', 331, 227, 341, 227, 341, 237, 331, 237, 1], ['page', 345, 227, 366, 227, 366, 237, 345, 237, 1], ['2', 370, 227, 375, 227, 375, 237, 370, 237, 1], ['...', 376, 227, 387, 227, 387, 237, 376, 237, 1], ['Simple', 65, 50, 145, 49, 145, 73, 65, 74, 1], ['PDF', 155, 49, 206, 48, 206, 71, 155, 72, 1], ['File', 216, 48, 257, 47, 257, 71, 216, 72, 1], ['2', 266, 48, 281, 48, 281, 71, 266, 71, 1], ['...', 71, 95, 81, 95, 81, 105, 71, 105, 1], ['continued', 81, 95, 123, 95, 123, 105, 81, 105, 1], ['from', 125, 95, 145, 95, 145, 105, 125, 105, 1], ['page', 149, 95, 170, 95, 170, 105, 149, 105, 1], ['1.', 174, 95, 182, 95, 182, 105, 174, 105, 1], ['Yet', 185, 95, 200, 95, 200, 105, 185, 105, 1], ['more', 203, 95, 225, 95, 225, 105, 203, 105, 1], ['text', 228, 95, 244, 95, 244, 105, 228, 105, 1], ['.', 244, 95, 246, 95, 246, 105, 244, 105, 1], ['And', 249, 95, 268, 95, 268, 105, 249, 105, 1], ['more', 270, 95, 292, 95, 292, 105, 270, 105, 1], ['text', 295, 95, 312, 95, 312, 105, 295, 105, 1], ['.', 313, 95, 315, 95, 315, 105, 313, 105, 1], ['And', 317, 95, 335, 95, 335, 105, 317, 105, 1], ['more', 338, 95, 360, 95, 360, 105, 338, 105, 1], ['text', 363, 95, 380, 95, 380, 105, 363, 105, 1], ['.', 380, 95, 384, 95, 384, 105, 380, 105, 1], ['And', 71, 107, 89, 107, 89, 115, 71, 115, 1], ['more', 92, 107, 114, 107, 114, 115, 92, 115, 1], ['text', 117, 107, 133, 107, 133, 115, 117, 115, 1], ['.', 134, 107, 136, 107, 136, 115, 134, 115, 1], ['And', 139, 107, 157, 107, 157, 115, 139, 115, 1], ['more', 160, 107, 182, 107, 182, 115, 160, 115, 1], ['text', 185, 107, 201, 107, 201, 115, 185, 115, 1], ['.', 202, 107, 204, 107, 204, 115, 202, 115, 1], ['And', 206, 107, 224, 107, 224, 115, 206, 115, 1], ['more', 228, 107, 250, 107, 250, 115, 228, 115, 1], ['text', 253, 107, 269, 107, 269, 115, 253, 115, 1], ['.', 270, 107, 272, 107, 272, 115, 270, 115, 1], ['And', 275, 107, 292, 107, 292, 115, 275, 115, 1], ['more', 296, 107, 317, 107, 317, 115, 296, 115, 1], ['text', 321, 107, 337, 107, 337, 115, 321, 115, 1], ['.', 338, 107, 340, 107, 340, 115, 338, 115, 1], ['And', 342, 107, 360, 107, 360, 115, 342, 115, 1], ['more', 364, 107, 385, 107, 385, 115, 364, 115, 1], ['text.Oh', 71, 119, 105, 119, 105, 129, 71, 129, 1], [',', 106, 119, 108, 119, 108, 129, 106, 129, 1], ['how', 112, 119, 130, 119, 130, 129, 112, 129, 1], ['boring', 133, 119, 160, 119, 160, 129, 133, 129, 1], ['typing', 164, 119, 189, 119, 189, 129, 164, 129, 1], ['this', 192, 119, 208, 119, 208, 129, 192, 129, 1], ['stuff', 212, 119, 231, 119, 231, 129, 212, 129, 1], ['.', 231, 119, 233, 119, 233, 129, 231, 129, 1], ['But', 236, 119, 251, 119, 251, 129, 236, 129, 1], ['not', 254, 119, 267, 119, 267, 129, 254, 129, 1], ['as', 271, 119, 281, 119, 281, 129, 271, 129, 1], ['boring', 284, 119, 311, 119, 311, 129, 284, 129, 1], ['as', 315, 119, 324, 119, 324, 129, 315, 129, 1], ['watching', 328, 119, 367, 119, 367, 129, 328, 129, 1], ['paint', 72, 131, 92, 131, 92, 140, 72, 140, 1], ['dry', 96, 131, 109, 131, 109, 140, 96, 140, 1], ['.', 110, 131, 112, 131, 112, 140, 110, 140, 1], ['And', 114, 131, 133, 131, 133, 140, 114, 140, 1], ['more', 136, 131, 158, 131, 158, 140, 136, 140, 1], ['text', 161, 131, 178, 131, 178, 140, 161, 140, 1], ['.', 178, 131, 179, 131, 179, 140, 178, 140, 1], ['And', 183, 131, 200, 131, 200, 140, 183, 140, 1], ['more', 204, 131, 225, 131, 225, 140, 204, 140, 1], ['text', 229, 131, 245, 131, 245, 140, 229, 140, 1], ['.', 245, 131, 247, 131, 247, 140, 245, 140, 1], ['And', 251, 131, 267, 131, 267, 140, 251, 140, 1], ['more', 272, 131, 293, 131, 293, 140, 272, 140, 1], ['text', 297, 131, 313, 131, 313, 140, 297, 140, 1], ['.', 313, 131, 315, 131, 315, 140, 313, 140, 1], ['And', 319, 131, 335, 131, 335, 140, 319, 140, 1], ['more', 340, 131, 362, 131, 362, 140, 340, 140, 1], ['text', 364, 131, 380, 131, 380, 140, 364, 140, 1], ['.', 381, 131, 383, 131, 383, 140, 381, 140, 1], ['Boring', 71, 143, 100, 143, 100, 153, 71, 153, 1], ['.', 100, 143, 103, 143, 103, 153, 100, 153, 1], ['More', 108, 143, 131, 143, 131, 153, 108, 153, 1], [',', 132, 143, 135, 143, 135, 153, 132, 153, 1], ['a', 137, 143, 142, 143, 142, 153, 137, 153, 1], ['little', 145, 143, 162, 143, 162, 153, 145, 153, 1], ['more', 167, 143, 188, 143, 188, 153, 167, 153, 1], ['text', 191, 143, 208, 143, 208, 153, 191, 153, 1], ['.', 208, 143, 210, 143, 210, 153, 208, 153, 1], ['The', 213, 143, 230, 143, 230, 153, 213, 153, 1], ['end', 233, 143, 248, 143, 248, 153, 233, 153, 1], [',', 250, 143, 252, 143, 252, 153, 250, 153, 1], ['and', 255, 143, 272, 143, 272, 153, 255, 153, 1], ['just', 274, 143, 291, 143, 291, 153, 274, 153, 1], ['as', 293, 143, 303, 143, 303, 153, 293, 153, 1], ['well', 306, 143, 326, 143, 326, 153, 306, 153, 1], ['.', 324, 143, 327, 143, 327, 153, 324, 153, 1]]


@pytest.mark.depends(name="test_read_pdf")
def test_reset_case_pdf(bot: BotCloudVisionPlugin):
    bot.reset_case()
    assert not bot._to_lowercase
    assert not bot._to_uppercase


@pytest.mark.depends(name="test_reset_case_pdf")
def test_upper_case_pdf(bot: BotCloudVisionPlugin):
    bot.to_upper_case()
    assert not bot._to_lowercase
    assert bot._to_uppercase
    bot.read(filepath=PATH_PDF)


@pytest.mark.depends(name="test_upper_case_pdf")
def test_read_pdf_uppercase(bot: BotCloudVisionPlugin):
    assert bot.full_text() == '\nA SIMPLE PDF FILE\nTHIS IS A SMALL DEMONSTRATION .PDF FILE-\nJUST FOR USE IN THE VIRTUAL MECHANICS TUTORIALS. MORE TEXT. AND MORE\nTEXT. AND MORE TEXT. AND MORE TEXT. AND MORE TEXT.\nAND MORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE\nTEXT. AND MORE TEXT. BORING, ZZZZZ. AND MORE TEXT. AND MORE TEXT. AND\nMORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE TEXT.\nAND MORE TEXT. AND MORE TEXT.\nAND MORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE\nTEXT. AND MORE TEXT. AND MORE TEXT. EVEN MORE. CONTINUED ON PAGE 2...\nSIMPLE PDF FILE 2\n...CONTINUED FROM PAGE 1. YET MORE TEXT. AND MORE TEXT. AND MORE TEXT.\nAND MORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE\nTEXT.OH, HOW BORING TYPING THIS STUFF. BUT NOT AS BORING AS WATCHING\nPAINT DRY. AND MORE TEXT. AND MORE TEXT. AND MORE TEXT. AND MORE TEXT.\nBORING. MORE, A LITTLE MORE TEXT. THE END, AND JUST AS WELL.'



@pytest.mark.depends(name="test_upper_case_pdf")
def test_entries_pdf_uppercase(bot: BotCloudVisionPlugin):
    assert bot.entries() == [['A', 64, 50, 82, 50, 82, 74, 64, 74, 1], ['Simple', 90, 49, 170, 48, 170, 72, 90, 73, 1], ['PDF', 180, 47, 231, 46, 231, 71, 180, 72, 1], ['File', 241, 46, 283, 45, 283, 70, 241, 71, 1], ['This', 71, 95, 90, 95, 90, 105, 71, 105, 1], ['is', 93, 95, 100, 95, 100, 105, 93, 105, 1], ['a', 103, 95, 109, 95, 109, 105, 103, 105, 1], ['small', 111, 95, 135, 95, 135, 105, 111, 105, 1], ['demonstration', 137, 95, 199, 95, 199, 105, 137, 105, 1], ['.pdf', 204, 95, 220, 95, 220, 105, 204, 105, 1], ['file', 222, 95, 235, 95, 235, 105, 222, 105, 1], ['just', 70, 119, 88, 119, 88, 128, 70, 128, 1], ['for', 89, 119, 102, 119, 102, 128, 89, 128, 1], ['use', 104, 119, 121, 119, 121, 128, 104, 128, 1], ['in', 123, 119, 130, 119, 130, 128, 123, 128, 1], ['the', 133, 119, 148, 119, 148, 128, 133, 128, 1], ['Virtual', 150, 119, 178, 119, 178, 128, 150, 128, 1], ['Mechanics', 182, 119, 229, 119, 229, 128, 182, 128, 1], ['tutorials', 231, 119, 266, 119, 266, 128, 231, 128, 1], ['.', 267, 119, 269, 119, 269, 128, 267, 128, 1], ['More', 273, 119, 294, 119, 294, 128, 273, 128, 1], ['text', 298, 119, 314, 119, 314, 128, 298, 128, 1], ['.', 315, 119, 317, 119, 317, 128, 315, 128, 1], ['And', 319, 119, 337, 119, 337, 128, 319, 128, 1], ['more', 341, 119, 362, 119, 362, 128, 341, 128, 1], ['text', 71, 131, 88, 131, 88, 140, 71, 140, 1], ['.', 88, 131, 90, 131, 90, 140, 88, 140, 1], ['And', 92, 131, 110, 131, 110, 140, 92, 140, 1], ['more', 114, 131, 136, 131, 136, 140, 114, 140, 1], ['text', 139, 131, 156, 131, 156, 140, 139, 140, 1], ['.', 156, 131, 158, 131, 158, 140, 156, 140, 1], ['And', 160, 131, 179, 131, 179, 140, 160, 140, 1], ['more', 181, 131, 203, 131, 203, 140, 181, 140, 1], ['text', 206, 131, 223, 131, 223, 140, 206, 140, 1], ['.', 223, 131, 225, 131, 225, 140, 223, 140, 1], ['And', 228, 131, 245, 131, 245, 140, 228, 140, 1], ['more', 249, 131, 272, 131, 272, 140, 249, 140, 1], ['text', 274, 131, 291, 131, 291, 140, 274, 140, 1], ['.', 290, 131, 294, 131, 294, 140, 290, 140, 1], ['And', 71, 155, 89, 155, 89, 163, 71, 163, 1], ['more', 92, 155, 114, 155, 114, 163, 92, 163, 1], ['text', 117, 155, 133, 155, 133, 163, 117, 163, 1], ['.', 134, 155, 136, 155, 136, 163, 134, 163, 1], ['And', 139, 155, 156, 155, 156, 163, 139, 163, 1], ['more', 160, 155, 182, 155, 182, 163, 160, 163, 1], ['text', 185, 155, 201, 155, 201, 163, 185, 163, 1], ['.', 202, 155, 204, 155, 204, 163, 202, 163, 1], ['And', 206, 155, 224, 155, 224, 163, 206, 163, 1], ['more', 228, 155, 250, 155, 250, 163, 228, 163, 1], ['text', 253, 155, 269, 155, 269, 163, 253, 163, 1], ['.', 270, 155, 272, 155, 272, 163, 270, 163, 1], ['And', 275, 155, 292, 155, 292, 163, 275, 163, 1], ['more', 296, 155, 317, 155, 317, 163, 296, 163, 1], ['text', 321, 155, 337, 155, 337, 163, 321, 163, 1], ['.', 338, 155, 340, 155, 340, 163, 338, 163, 1], ['And', 342, 155, 360, 155, 360, 163, 342, 163, 1], ['more', 364, 155, 385, 155, 385, 163, 364, 163, 1], ['text', 71, 167, 87, 167, 87, 176, 71, 176, 1], ['.', 88, 167, 90, 167, 90, 176, 88, 176, 1], ['And', 93, 167, 110, 167, 110, 176, 93, 176, 1], ['more', 114, 167, 135, 167, 135, 176, 114, 176, 1], ['text', 139, 167, 156, 167, 156, 176, 139, 176, 1], ['.', 155, 167, 157, 167, 157, 176, 155, 176, 1], ['Boring', 161, 167, 189, 167, 189, 176, 161, 176, 1], [',', 191, 167, 192, 167, 192, 176, 191, 176, 1], ['zzzzz', 195, 167, 220, 167, 220, 176, 195, 176, 1], ['.', 220, 167, 222, 167, 222, 176, 220, 176, 1], ['And', 226, 167, 243, 167, 243, 176, 226, 176, 1], ['more', 246, 167, 269, 167, 269, 176, 246, 176, 1], ['text', 272, 167, 288, 167, 288, 176, 272, 176, 1], ['.', 288, 167, 290, 167, 290, 176, 288, 176, 1], ['And', 293, 167, 310, 167, 310, 176, 293, 176, 1], ['more', 315, 167, 336, 167, 336, 176, 315, 176, 1], ['text', 340, 167, 355, 167, 355, 176, 340, 176, 1], ['.', 356, 167, 359, 167, 359, 176, 356, 176, 1], ['And', 361, 167, 379, 167, 379, 176, 361, 176, 1], ['more', 71, 180, 93, 180, 93, 188, 71, 188, 1], ['text', 96, 180, 114, 180, 114, 188, 96, 188, 1], ['.', 113, 180, 115, 180, 115, 188, 113, 188, 1], ['And', 118, 180, 136, 180, 136, 188, 118, 188, 1], ['more', 139, 180, 162, 180, 162, 188, 139, 188, 1], ['text', 164, 180, 181, 180, 181, 188, 164, 188, 1], ['.', 182, 180, 184, 180, 184, 188, 182, 188, 1], ['And', 186, 180, 203, 180, 203, 188, 186, 188, 1], ['more', 207, 180, 229, 180, 229, 188, 207, 188, 1], ['text', 232, 180, 248, 180, 248, 188, 232, 188, 1], ['.', 249, 180, 251, 180, 251, 188, 249, 188, 1], ['And', 254, 180, 271, 180, 271, 188, 254, 188, 1], ['more', 275, 180, 297, 180, 297, 188, 275, 188, 1], ['text', 300, 180, 316, 180, 316, 188, 300, 188, 1], ['.', 317, 180, 319, 180, 319, 188, 317, 188, 1], ['And', 322, 180, 339, 180, 339, 188, 322, 188, 1], ['more', 343, 180, 365, 180, 365, 188, 343, 188, 1], ['text', 368, 180, 385, 180, 385, 188, 368, 188, 1], ['.', 384, 180, 386, 180, 386, 188, 384, 188, 1], ['And', 71, 191, 89, 191, 89, 200, 71, 200, 1], ['more', 92, 191, 114, 191, 114, 200, 92, 200, 1], ['text', 117, 191, 134, 191, 134, 200, 117, 200, 1], ['.', 134, 191, 136, 191, 136, 200, 134, 200, 1], ['And', 139, 191, 156, 191, 156, 200, 139, 200, 1], ['more', 160, 191, 182, 191, 182, 200, 160, 200, 1], ['text', 184, 191, 202, 191, 202, 200, 184, 200, 1], ['.', 202, 191, 205, 191, 205, 200, 202, 200, 1], ['And', 71, 214, 89, 214, 89, 223, 71, 223, 1], ['more', 92, 214, 114, 214, 114, 223, 92, 223, 1], ['text', 117, 214, 134, 214, 134, 223, 117, 223, 1], ['.', 134, 214, 136, 214, 136, 223, 134, 223, 1], ['And', 139, 214, 156, 214, 156, 223, 139, 223, 1], ['more', 160, 214, 181, 214, 181, 223, 160, 223, 1], ['text', 185, 214, 201, 214, 201, 223, 185, 223, 1], ['.', 202, 214, 204, 214, 204, 223, 202, 223, 1], ['And', 207, 214, 224, 214, 224, 223, 207, 223, 1], ['more', 228, 214, 249, 214, 249, 223, 228, 223, 1], ['text', 253, 214, 269, 214, 269, 223, 253, 223, 1], ['.', 269, 214, 271, 214, 271, 223, 269, 223, 1], ['And', 275, 214, 291, 214, 291, 223, 275, 223, 1], ['more', 296, 214, 317, 214, 317, 223, 296, 223, 1], ['text', 321, 214, 337, 214, 337, 223, 321, 223, 1], ['.', 337, 214, 339, 214, 339, 223, 337, 223, 1], ['And', 342, 214, 360, 214, 360, 223, 342, 223, 1], ['more', 364, 214, 386, 214, 386, 223, 364, 223, 1], ['text', 71, 227, 88, 227, 88, 237, 71, 237, 1], ['.', 88, 227, 90, 227, 90, 237, 88, 237, 1], ['And', 93, 227, 110, 227, 110, 237, 93, 237, 1], ['more', 113, 227, 136, 227, 136, 237, 113, 237, 1], ['text', 139, 227, 155, 227, 155, 237, 139, 237, 1], ['.', 155, 227, 157, 227, 157, 237, 155, 237, 1], ['And', 161, 227, 178, 227, 178, 237, 161, 237, 1], ['more', 182, 227, 203, 227, 203, 237, 182, 237, 1], ['text', 206, 227, 223, 227, 223, 237, 206, 237, 1], ['.', 224, 227, 226, 227, 226, 237, 224, 237, 1], ['Even', 229, 227, 250, 227, 250, 237, 229, 237, 1], ['more', 254, 227, 276, 227, 276, 237, 254, 237, 1], ['.', 278, 227, 280, 227, 280, 237, 278, 237, 1], ['Continued', 283, 227, 327, 227, 327, 237, 283, 237, 1], ['on', 331, 227, 341, 227, 341, 237, 331, 237, 1], ['page', 345, 227, 366, 227, 366, 237, 345, 237, 1], ['2', 370, 227, 375, 227, 375, 237, 370, 237, 1], ['...', 376, 227, 387, 227, 387, 237, 376, 237, 1], ['Simple', 65, 50, 145, 49, 145, 73, 65, 74, 1], ['PDF', 155, 49, 206, 48, 206, 71, 155, 72, 1], ['File', 216, 48, 257, 47, 257, 71, 216, 72, 1], ['2', 266, 48, 281, 48, 281, 71, 266, 71, 1], ['...', 71, 95, 81, 95, 81, 105, 71, 105, 1], ['continued', 81, 95, 123, 95, 123, 105, 81, 105, 1], ['from', 125, 95, 145, 95, 145, 105, 125, 105, 1], ['page', 149, 95, 170, 95, 170, 105, 149, 105, 1], ['1.', 174, 95, 182, 95, 182, 105, 174, 105, 1], ['Yet', 185, 95, 200, 95, 200, 105, 185, 105, 1], ['more', 203, 95, 225, 95, 225, 105, 203, 105, 1], ['text', 228, 95, 244, 95, 244, 105, 228, 105, 1], ['.', 244, 95, 246, 95, 246, 105, 244, 105, 1], ['And', 249, 95, 268, 95, 268, 105, 249, 105, 1], ['more', 270, 95, 292, 95, 292, 105, 270, 105, 1], ['text', 295, 95, 312, 95, 312, 105, 295, 105, 1], ['.', 313, 95, 315, 95, 315, 105, 313, 105, 1], ['And', 317, 95, 335, 95, 335, 105, 317, 105, 1], ['more', 338, 95, 360, 95, 360, 105, 338, 105, 1], ['text', 363, 95, 380, 95, 380, 105, 363, 105, 1], ['.', 380, 95, 384, 95, 384, 105, 380, 105, 1], ['And', 71, 107, 89, 107, 89, 115, 71, 115, 1], ['more', 92, 107, 114, 107, 114, 115, 92, 115, 1], ['text', 117, 107, 133, 107, 133, 115, 117, 115, 1], ['.', 134, 107, 136, 107, 136, 115, 134, 115, 1], ['And', 139, 107, 157, 107, 157, 115, 139, 115, 1], ['more', 160, 107, 182, 107, 182, 115, 160, 115, 1], ['text', 185, 107, 201, 107, 201, 115, 185, 115, 1], ['.', 202, 107, 204, 107, 204, 115, 202, 115, 1], ['And', 206, 107, 224, 107, 224, 115, 206, 115, 1], ['more', 228, 107, 250, 107, 250, 115, 228, 115, 1], ['text', 253, 107, 269, 107, 269, 115, 253, 115, 1], ['.', 270, 107, 272, 107, 272, 115, 270, 115, 1], ['And', 275, 107, 292, 107, 292, 115, 275, 115, 1], ['more', 296, 107, 317, 107, 317, 115, 296, 115, 1], ['text', 321, 107, 337, 107, 337, 115, 321, 115, 1], ['.', 338, 107, 340, 107, 340, 115, 338, 115, 1], ['And', 342, 107, 360, 107, 360, 115, 342, 115, 1], ['more', 364, 107, 385, 107, 385, 115, 364, 115, 1], ['text.Oh', 71, 119, 105, 119, 105, 129, 71, 129, 1], [',', 106, 119, 108, 119, 108, 129, 106, 129, 1], ['how', 112, 119, 130, 119, 130, 129, 112, 129, 1], ['boring', 133, 119, 160, 119, 160, 129, 133, 129, 1], ['typing', 164, 119, 189, 119, 189, 129, 164, 129, 1], ['this', 192, 119, 208, 119, 208, 129, 192, 129, 1], ['stuff', 212, 119, 231, 119, 231, 129, 212, 129, 1], ['.', 231, 119, 233, 119, 233, 129, 231, 129, 1], ['But', 236, 119, 251, 119, 251, 129, 236, 129, 1], ['not', 254, 119, 267, 119, 267, 129, 254, 129, 1], ['as', 271, 119, 281, 119, 281, 129, 271, 129, 1], ['boring', 284, 119, 311, 119, 311, 129, 284, 129, 1], ['as', 315, 119, 324, 119, 324, 129, 315, 129, 1], ['watching', 328, 119, 367, 119, 367, 129, 328, 129, 1], ['paint', 72, 131, 92, 131, 92, 140, 72, 140, 1], ['dry', 96, 131, 109, 131, 109, 140, 96, 140, 1], ['.', 110, 131, 112, 131, 112, 140, 110, 140, 1], ['And', 114, 131, 133, 131, 133, 140, 114, 140, 1], ['more', 136, 131, 158, 131, 158, 140, 136, 140, 1], ['text', 161, 131, 178, 131, 178, 140, 161, 140, 1], ['.', 178, 131, 179, 131, 179, 140, 178, 140, 1], ['And', 183, 131, 200, 131, 200, 140, 183, 140, 1], ['more', 204, 131, 225, 131, 225, 140, 204, 140, 1], ['text', 229, 131, 245, 131, 245, 140, 229, 140, 1], ['.', 245, 131, 247, 131, 247, 140, 245, 140, 1], ['And', 251, 131, 267, 131, 267, 140, 251, 140, 1], ['more', 272, 131, 293, 131, 293, 140, 272, 140, 1], ['text', 297, 131, 313, 131, 313, 140, 297, 140, 1], ['.', 313, 131, 315, 131, 315, 140, 313, 140, 1], ['And', 319, 131, 335, 131, 335, 140, 319, 140, 1], ['more', 340, 131, 362, 131, 362, 140, 340, 140, 1], ['text', 364, 131, 380, 131, 380, 140, 364, 140, 1], ['.', 381, 131, 383, 131, 383, 140, 381, 140, 1], ['Boring', 71, 143, 100, 143, 100, 153, 71, 153, 1], ['.', 100, 143, 103, 143, 103, 153, 100, 153, 1], ['More', 108, 143, 131, 143, 131, 153, 108, 153, 1], [',', 132, 143, 135, 143, 135, 153, 132, 153, 1], ['a', 137, 143, 142, 143, 142, 153, 137, 153, 1], ['little', 145, 143, 162, 143, 162, 153, 145, 153, 1], ['more', 167, 143, 188, 143, 188, 153, 167, 153, 1], ['text', 191, 143, 208, 143, 208, 153, 191, 153, 1], ['.', 208, 143, 210, 143, 210, 153, 208, 153, 1], ['The', 213, 143, 230, 143, 230, 153, 213, 153, 1], ['end', 233, 143, 248, 143, 248, 153, 233, 153, 1], [',', 250, 143, 252, 143, 252, 153, 250, 153, 1], ['and', 255, 143, 272, 143, 272, 153, 255, 153, 1], ['just', 274, 143, 291, 143, 291, 153, 274, 153, 1], ['as', 293, 143, 303, 143, 303, 153, 293, 153, 1], ['well', 306, 143, 326, 143, 326, 153, 306, 153, 1], ['.', 324, 143, 327, 143, 327, 153, 324, 153, 1]]


@pytest.mark.depends(name=["test_read_pdf_uppercase", "test_entries_pdf_uppercase"])
def test_lower_case_pdf(bot: BotCloudVisionPlugin):
    bot.to_lower_case()
    assert bot._to_lowercase
    assert not bot._to_uppercase


@pytest.mark.depends(name="test_lower_case_pdf")
def test_read_pdf_lowercase(bot: BotCloudVisionPlugin):
    bot.read(filepath=PATH_PNG)
    assert bot.full_text() == '\na simple pdf file\nthis is a small demonstration .pdf file -\njust for use in the virtual mechanics tutorials. more text. and more\ntext. and more text. and more text. and more text.\nand more text. and more text. and more text. and more text. and more\ntext. and more text. boring, zzzzz. and more text. and more text. and\nmore text. and more text. and more text. and more text. and more text.\nand more text. and more text.\nand more text. and more text. and more text. and more text. and more\ntext. and more text. and more text. even more. continued on page 2\nsimple pdf file 2\n...continued from page 1. yet more text. and more text. and more text.\nand more text. and more text. and more text. and more text. and more\ntext. oh, how boring typing this stuff. but not as boring as watching\npaint dry. and more text. and more text. and more text. and more text.\nboring. more, a little more text. the end, and just as well.'


@pytest.mark.depends(name="test_lower_case_pdf")
def test_entries_png_lowercase(bot: BotCloudVisionPlugin):
    bot.read(filepath=PATH_PNG)
    assert bot.entries() == [['A', 178, 140, 225, 139, 226, 204, 179, 205, 1], ['Simple', 252, 138, 474, 134, 475, 199, 253, 203, 1], ['PDF', 504, 134, 645, 131, 646, 196, 505, 199, 1], ['File', 675, 130, 788, 128, 789, 194, 676, 196, 1], ['This', 200, 266, 252, 266, 252, 292, 200, 292, 1], ['is', 261, 266, 279, 266, 279, 292, 261, 292, 1], ['a', 288, 266, 303, 266, 303, 292, 288, 292, 1], ['small', 311, 266, 376, 266, 376, 292, 311, 292, 1], ['demonstration', 384, 266, 557, 266, 557, 292, 384, 292, 1], ['.pdf', 569, 266, 613, 266, 613, 292, 569, 292, 1], ['file', 621, 266, 656, 266, 656, 292, 621, 292, 1], ['-', 665, 266, 674, 266, 674, 292, 665, 292, 1], ['just', 198, 332, 244, 332, 244, 357, 198, 357, 1], ['for', 249, 332, 284, 332, 284, 357, 249, 357, 1], ['use', 291, 332, 334, 332, 334, 357, 291, 357, 1], ['in', 344, 332, 363, 332, 363, 357, 344, 357, 1], ['the', 372, 332, 410, 332, 410, 357, 372, 357, 1], ['Virtual', 420, 332, 497, 332, 497, 357, 420, 357, 1], ['Mechanics', 508, 332, 636, 332, 636, 357, 508, 357, 1], ['tutorials', 645, 332, 741, 332, 741, 357, 645, 357, 1], ['.', 746, 332, 750, 332, 750, 357, 746, 357, 1], ['More', 761, 332, 820, 332, 820, 357, 761, 357, 1], ['text', 830, 332, 874, 332, 874, 357, 830, 357, 1], ['.', 877, 332, 880, 332, 880, 357, 877, 357, 1], ['And', 890, 332, 936, 332, 936, 357, 890, 357, 1], ['more', 949, 332, 1010, 332, 1010, 357, 949, 357, 1], ['text', 198, 366, 244, 366, 244, 387, 198, 387, 1], ['.', 247, 366, 251, 366, 251, 387, 247, 387, 1], ['And', 260, 366, 309, 366, 309, 387, 260, 387, 1], ['more', 318, 366, 379, 366, 379, 387, 318, 387, 1], ['text', 388, 366, 433, 366, 433, 387, 388, 387, 1], ['.', 435, 366, 438, 366, 438, 387, 435, 387, 1], ['And', 449, 366, 495, 366, 495, 387, 449, 387, 1], ['more', 507, 366, 567, 366, 567, 387, 507, 387, 1], ['text', 576, 366, 621, 366, 621, 387, 576, 387, 1], ['.', 624, 366, 627, 366, 627, 387, 624, 387, 1], ['And', 637, 366, 684, 366, 684, 387, 637, 387, 1], ['more', 695, 366, 756, 366, 756, 387, 695, 387, 1], ['text', 764, 366, 810, 366, 810, 387, 764, 387, 1], ['.', 812, 366, 816, 366, 816, 387, 812, 387, 1], ['And', 198, 432, 248, 432, 248, 453, 198, 453, 1], ['more', 258, 432, 318, 432, 318, 453, 258, 453, 1], ['text', 327, 432, 372, 432, 372, 453, 327, 453, 1], ['.', 375, 432, 378, 432, 378, 453, 375, 453, 1], ['And', 388, 432, 435, 432, 435, 453, 388, 453, 1], ['more', 447, 432, 507, 432, 507, 453, 447, 453, 1], ['text', 516, 432, 561, 432, 561, 453, 516, 453, 1], ['.', 564, 432, 567, 432, 567, 453, 564, 453, 1], ['And', 577, 432, 624, 432, 624, 453, 577, 453, 1], ['more', 635, 432, 695, 432, 695, 453, 635, 453, 1], ['text', 704, 432, 749, 432, 749, 453, 704, 453, 1], ['.', 752, 432, 755, 432, 755, 453, 752, 453, 1], ['And', 765, 432, 811, 432, 811, 453, 765, 453, 1], ['more', 824, 432, 884, 432, 884, 453, 824, 453, 1], ['text', 893, 432, 938, 432, 938, 453, 893, 453, 1], ['.', 940, 432, 943, 432, 943, 453, 940, 453, 1], ['And', 954, 432, 1001, 432, 1001, 453, 954, 453, 1], ['more', 1011, 432, 1073, 432, 1073, 453, 1011, 453, 1], ['text', 199, 466, 245, 466, 245, 490, 199, 490, 1], ['.', 247, 466, 251, 466, 251, 490, 247, 490, 1], ['And', 260, 466, 307, 466, 307, 490, 260, 490, 1], ['more', 319, 466, 380, 466, 380, 490, 319, 490, 1], ['text', 388, 466, 432, 466, 432, 490, 388, 490, 1], ['.', 435, 466, 438, 466, 438, 490, 435, 490, 1], ['Boring', 450, 466, 526, 466, 526, 490, 450, 490, 1], [',', 531, 466, 535, 466, 535, 490, 531, 490, 1], ['zzzzz', 545, 466, 612, 466, 612, 490, 545, 490, 1], ['.', 616, 466, 620, 466, 620, 490, 616, 490, 1], ['And', 629, 466, 675, 466, 675, 490, 629, 490, 1], ['more', 688, 466, 748, 466, 748, 490, 688, 490, 1], ['text', 757, 466, 801, 466, 801, 490, 757, 490, 1], ['.', 805, 466, 807, 466, 807, 490, 805, 490, 1], ['And', 818, 466, 865, 466, 865, 490, 818, 490, 1], ['more', 877, 466, 936, 466, 936, 490, 877, 490, 1], ['text', 944, 466, 990, 466, 990, 490, 944, 490, 1], ['.', 993, 466, 997, 466, 997, 490, 993, 490, 1], ['And', 1006, 466, 1053, 466, 1053, 490, 1006, 490, 1], ['more', 200, 499, 261, 499, 261, 519, 200, 519, 1], ['text', 269, 499, 316, 499, 316, 519, 269, 519, 1], ['.', 318, 499, 322, 499, 322, 519, 318, 519, 1], ['And', 331, 499, 378, 499, 378, 519, 331, 519, 1], ['more', 390, 499, 450, 499, 450, 519, 390, 519, 1], ['text', 459, 499, 503, 499, 503, 519, 459, 519, 1], ['.', 507, 499, 510, 499, 510, 519, 507, 519, 1], ['And', 520, 499, 566, 499, 566, 519, 520, 519, 1], ['more', 578, 499, 638, 499, 638, 519, 578, 519, 1], ['text', 647, 499, 692, 499, 692, 519, 647, 519, 1], ['.', 695, 499, 698, 499, 698, 519, 695, 519, 1], ['And', 709, 499, 755, 499, 755, 519, 709, 519, 1], ['more', 766, 499, 827, 499, 827, 519, 766, 519, 1], ['text', 835, 499, 881, 499, 881, 519, 835, 519, 1], ['.', 883, 499, 886, 499, 886, 519, 883, 519, 1], ['And', 896, 499, 943, 499, 943, 519, 896, 519, 1], ['more', 955, 499, 1015, 499, 1015, 519, 955, 519, 1], ['text', 1023, 499, 1069, 499, 1069, 519, 1023, 519, 1], ['.', 1071, 499, 1075, 499, 1075, 519, 1071, 519, 1], ['And', 199, 532, 248, 532, 248, 553, 199, 553, 1], ['more', 257, 532, 318, 532, 318, 553, 257, 553, 1], ['text', 326, 532, 373, 532, 373, 553, 326, 553, 1], ['.', 375, 532, 378, 532, 378, 553, 375, 553, 1], ['And', 388, 532, 435, 532, 435, 553, 388, 553, 1], ['more', 447, 532, 507, 532, 507, 553, 447, 553, 1], ['text', 515, 532, 561, 532, 561, 553, 515, 553, 1], ['.', 563, 532, 567, 532, 567, 553, 563, 553, 1], ['And', 199, 599, 248, 599, 248, 619, 199, 619, 1], ['more', 258, 599, 318, 599, 318, 619, 258, 619, 1], ['text', 327, 599, 372, 599, 372, 619, 327, 619, 1], ['.', 375, 599, 378, 599, 378, 619, 375, 619, 1], ['And', 388, 599, 435, 599, 435, 619, 388, 619, 1], ['more', 447, 599, 507, 599, 507, 619, 447, 619, 1], ['text', 516, 599, 560, 599, 560, 619, 516, 619, 1], ['.', 564, 599, 567, 599, 567, 619, 564, 619, 1], ['And', 577, 599, 624, 599, 624, 619, 577, 619, 1], ['more', 636, 599, 696, 599, 696, 619, 636, 619, 1], ['text', 704, 599, 750, 599, 750, 619, 704, 619, 1], ['.', 752, 599, 755, 599, 755, 619, 752, 619, 1], ['And', 765, 599, 811, 599, 811, 619, 765, 619, 1], ['more', 824, 599, 883, 599, 883, 619, 824, 619, 1], ['text', 893, 599, 937, 599, 937, 619, 893, 619, 1], ['.', 941, 599, 944, 599, 944, 619, 941, 619, 1], ['And', 954, 599, 1001, 599, 1001, 619, 954, 619, 1], ['more', 1011, 599, 1073, 599, 1073, 619, 1011, 619, 1], ['text', 198, 632, 244, 632, 244, 657, 198, 657, 1], ['.', 247, 632, 251, 632, 251, 657, 247, 657, 1], ['And', 260, 632, 308, 632, 308, 657, 260, 657, 1], ['more', 318, 632, 379, 632, 379, 657, 318, 657, 1], ['text', 388, 632, 433, 632, 433, 657, 388, 657, 1], ['.', 436, 632, 439, 632, 439, 657, 436, 657, 1], ['And', 449, 632, 495, 632, 495, 657, 449, 657, 1], ['more', 507, 632, 567, 632, 567, 657, 507, 657, 1], ['text', 577, 632, 620, 632, 620, 657, 577, 657, 1], ['.', 624, 632, 627, 632, 627, 657, 624, 657, 1], ['Even', 640, 632, 698, 632, 698, 657, 640, 657, 1], ['more', 710, 632, 769, 632, 769, 657, 710, 657, 1], ['.', 774, 632, 778, 632, 778, 657, 774, 657, 1], ['Continued', 788, 632, 910, 632, 910, 657, 788, 657, 1], ['on', 922, 632, 949, 632, 949, 657, 922, 657, 1], ['page', 960, 632, 1020, 632, 1020, 657, 960, 657, 1], ['2', 1029, 632, 1043, 632, 1043, 657, 1029, 657, 1], ['Simple', 196, 751, 418, 747, 419, 815, 197, 819, 1], ['PDF', 445, 747, 587, 744, 588, 811, 446, 814, 1], ['File', 613, 743, 734, 741, 735, 809, 614, 811, 1], ['2', 751, 741, 797, 740, 798, 807, 752, 808, 1], ['...', 214, 882, 236, 882, 236, 907, 214, 907, 1], ['continued', 237, 882, 355, 882, 355, 907, 237, 907, 1], ['from', 364, 882, 418, 882, 418, 907, 364, 907, 1], ['page', 429, 882, 488, 882, 488, 907, 429, 907, 1], ['1.', 500, 882, 519, 882, 519, 907, 500, 907, 1], ['Yet', 529, 882, 570, 882, 570, 907, 529, 907, 1], ['more', 580, 882, 640, 882, 640, 907, 580, 907, 1], ['text', 649, 882, 694, 882, 694, 907, 649, 907, 1], ['.', 697, 882, 701, 882, 701, 907, 697, 907, 1], ['And', 709, 882, 757, 882, 757, 907, 709, 907, 1], ['more', 768, 882, 828, 882, 828, 907, 768, 907, 1], ['text', 837, 882, 882, 882, 882, 907, 837, 907, 1], ['.', 885, 882, 889, 882, 889, 907, 885, 907, 1], ['And', 898, 882, 945, 882, 945, 907, 898, 907, 1], ['more', 956, 882, 1017, 882, 1017, 907, 956, 907, 1], ['text', 1025, 882, 1071, 882, 1071, 907, 1025, 907, 1], ['.', 1072, 882, 1078, 882, 1078, 907, 1072, 907, 1], ['And', 214, 915, 262, 915, 262, 936, 214, 936, 1], ['more', 272, 915, 332, 915, 332, 936, 272, 936, 1], ['text', 340, 915, 386, 915, 386, 936, 340, 936, 1], ['.', 390, 915, 393, 915, 393, 936, 390, 936, 1], ['And', 402, 915, 449, 915, 449, 936, 402, 936, 1], ['more', 461, 915, 521, 915, 521, 936, 461, 936, 1], ['text', 530, 915, 575, 915, 575, 936, 530, 936, 1], ['.', 578, 915, 581, 915, 581, 936, 578, 936, 1], ['And', 591, 915, 638, 915, 638, 936, 591, 936, 1], ['more', 649, 915, 710, 915, 710, 936, 649, 936, 1], ['text', 718, 915, 763, 915, 763, 936, 718, 936, 1], ['.', 766, 915, 769, 915, 769, 936, 766, 936, 1], ['And', 779, 915, 825, 915, 825, 936, 779, 936, 1], ['more', 838, 915, 898, 915, 898, 936, 838, 936, 1], ['text', 907, 915, 952, 915, 952, 936, 907, 936, 1], ['.', 955, 915, 957, 915, 957, 936, 955, 936, 1], ['And', 968, 915, 1014, 915, 1014, 936, 968, 936, 1], ['more', 1025, 915, 1088, 915, 1088, 936, 1025, 936, 1], ['text', 212, 947, 259, 947, 259, 974, 212, 974, 1], ['.', 261, 947, 266, 947, 266, 974, 261, 974, 1], ['Oh', 275, 947, 309, 947, 309, 974, 275, 974, 1], [',', 313, 947, 318, 947, 318, 974, 313, 974, 1], ['how', 327, 947, 375, 947, 375, 974, 327, 974, 1], ['boring', 386, 947, 460, 947, 460, 974, 386, 974, 1], ['typing', 470, 947, 542, 947, 542, 974, 470, 974, 1], ['this', 551, 947, 594, 947, 594, 974, 551, 974, 1], ['stuff', 604, 947, 655, 947, 655, 974, 604, 974, 1], ['.', 658, 947, 660, 947, 660, 974, 658, 974, 1], ['But', 673, 947, 712, 947, 712, 974, 673, 974, 1], ['not', 722, 947, 758, 947, 758, 974, 722, 974, 1], ['as', 768, 947, 794, 947, 794, 974, 768, 974, 1], ['boring', 805, 947, 879, 947, 879, 974, 805, 974, 1], ['as', 890, 947, 917, 947, 917, 974, 890, 974, 1], ['watching', 926, 947, 1035, 947, 1035, 974, 926, 974, 1], ['paint', 214, 981, 275, 981, 275, 1005, 214, 1005, 1], ['dry', 282, 981, 320, 981, 320, 1005, 282, 1005, 1], ['.', 322, 981, 328, 981, 328, 1005, 322, 1005, 1], ['And', 335, 981, 383, 981, 383, 1005, 335, 1005, 1], ['more', 395, 981, 454, 981, 454, 1005, 395, 1005, 1], ['text', 463, 981, 508, 981, 508, 1005, 463, 1005, 1], ['.', 511, 981, 515, 981, 515, 1005, 511, 1005, 1], ['And', 524, 981, 571, 981, 571, 1005, 524, 1005, 1], ['more', 583, 981, 643, 981, 643, 1005, 583, 1005, 1], ['text', 652, 981, 696, 981, 696, 1005, 652, 1005, 1], ['.', 700, 981, 704, 981, 704, 1005, 700, 1005, 1], ['And', 713, 981, 760, 981, 760, 1005, 713, 1005, 1], ['more', 772, 981, 831, 981, 831, 1005, 772, 1005, 1], ['text', 840, 981, 885, 981, 885, 1005, 840, 1005, 1], ['.', 888, 981, 891, 981, 891, 1005, 888, 1005, 1], ['And', 901, 981, 948, 981, 948, 1005, 901, 1005, 1], ['more', 960, 981, 1020, 981, 1020, 1005, 960, 1005, 1], ['text', 1028, 981, 1074, 981, 1074, 1005, 1028, 1005, 1], ['.', 1075, 981, 1081, 981, 1081, 1005, 1075, 1005, 1], ['Boring', 215, 1014, 292, 1014, 292, 1040, 215, 1040, 1], ['.', 296, 1014, 302, 1014, 302, 1040, 296, 1040, 1], ['More', 318, 1014, 380, 1014, 380, 1040, 318, 1040, 1], [',', 381, 1014, 386, 1014, 386, 1040, 381, 1040, 1], ['a', 396, 1014, 409, 1014, 409, 1040, 396, 1040, 1], ['little', 420, 1014, 467, 1014, 467, 1040, 420, 1040, 1], ['more', 478, 1014, 538, 1014, 538, 1040, 478, 1040, 1], ['text', 547, 1014, 592, 1014, 592, 1040, 547, 1040, 1], ['.', 595, 1014, 598, 1014, 598, 1040, 595, 1040, 1], ['The', 608, 1014, 653, 1014, 653, 1040, 608, 1040, 1], ['end', 664, 1014, 708, 1014, 708, 1040, 664, 1040, 1], [',', 711, 1014, 715, 1014, 715, 1040, 711, 1040, 1], ['and', 725, 1014, 769, 1014, 769, 1040, 725, 1040, 1], ['just', 777, 1014, 822, 1014, 822, 1040, 777, 1040, 1], ['as', 830, 1014, 858, 1014, 858, 1040, 830, 1040, 1], ['well', 866, 1014, 915, 1014, 915, 1040, 866, 1040, 1], ['.', 916, 1014, 921, 1014, 921, 1040, 916, 1040, 1]]
